Class: Google::Cloud::Container::V1beta1::AddonsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::AddonsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.
Instance Attribute Summary collapse
-
#agent_sandbox_config ⇒ ::Google::Cloud::Container::V1beta1::AgentSandboxConfig
Optional.
-
#cloud_run_config ⇒ ::Google::Cloud::Container::V1beta1::CloudRunConfig
Configuration for the Cloud Run addon.
-
#config_connector_config ⇒ ::Google::Cloud::Container::V1beta1::ConfigConnectorConfig
Configuration for the ConfigConnector add-on, a Kubernetes extension to manage hosted Google Cloud services through the Kubernetes API.
-
#dns_cache_config ⇒ ::Google::Cloud::Container::V1beta1::DnsCacheConfig
Configuration for NodeLocalDNS, a dns cache running on cluster nodes.
-
#gce_persistent_disk_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::GcePersistentDiskCsiDriverConfig
Configuration for the Compute Engine Persistent Disk CSI driver.
-
#gcp_filestore_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::GcpFilestoreCsiDriverConfig
Configuration for the Filestore CSI driver.
-
#gcs_fuse_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::GcsFuseCsiDriverConfig
Configuration for the Cloud Storage Fuse CSI driver.
-
#gke_backup_agent_config ⇒ ::Google::Cloud::Container::V1beta1::GkeBackupAgentConfig
Configuration for the Backup for GKE agent addon.
-
#high_scale_checkpointing_config ⇒ ::Google::Cloud::Container::V1beta1::HighScaleCheckpointingConfig
Configuration for the High Scale Checkpointing add-on.
-
#horizontal_pod_autoscaling ⇒ ::Google::Cloud::Container::V1beta1::HorizontalPodAutoscaling
Configuration for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
-
#http_load_balancing ⇒ ::Google::Cloud::Container::V1beta1::HttpLoadBalancing
Configuration for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
-
#istio_config ⇒ ::Google::Cloud::Container::V1beta1::IstioConfig
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#kalm_config ⇒ ::Google::Cloud::Container::V1beta1::KalmConfig
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#kubernetes_dashboard ⇒ ::Google::Cloud::Container::V1beta1::KubernetesDashboard
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#lustre_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::LustreCsiDriverConfig
Configuration for the Lustre CSI driver.
-
#network_policy_config ⇒ ::Google::Cloud::Container::V1beta1::NetworkPolicyConfig
Configuration for NetworkPolicy.
-
#node_readiness_config ⇒ ::Google::Cloud::Container::V1beta1::NodeReadinessConfig
Optional.
-
#parallelstore_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::ParallelstoreCsiDriverConfig
Configuration for the Cloud Storage Parallelstore CSI driver.
-
#pod_snapshot_config ⇒ ::Google::Cloud::Container::V1beta1::PodSnapshotConfig
Configuration for the Pod Snapshot feature.
-
#ray_operator_config ⇒ ::Google::Cloud::Container::V1beta1::RayOperatorConfig
Optional.
-
#slice_controller_config ⇒ ::Google::Cloud::Container::V1beta1::SliceControllerConfig
Optional.
-
#slurm_operator_config ⇒ ::Google::Cloud::Container::V1beta1::SlurmOperatorConfig
Configuration for the Slurm Operator.
-
#stateful_ha_config ⇒ ::Google::Cloud::Container::V1beta1::StatefulHAConfig
Optional.
Instance Attribute Details
#agent_sandbox_config ⇒ ::Google::Cloud::Container::V1beta1::AgentSandboxConfig
Returns Optional. Configuration for the AgentSandbox addon.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#cloud_run_config ⇒ ::Google::Cloud::Container::V1beta1::CloudRunConfig
Returns Configuration for the Cloud Run addon. The IstioConfig addon must be
enabled in order to enable Cloud Run addon. This option can only be enabled
at cluster creation time.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#config_connector_config ⇒ ::Google::Cloud::Container::V1beta1::ConfigConnectorConfig
Returns Configuration for the ConfigConnector add-on, a Kubernetes extension to manage hosted Google Cloud services through the Kubernetes API.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#dns_cache_config ⇒ ::Google::Cloud::Container::V1beta1::DnsCacheConfig
Returns Configuration for NodeLocalDNS, a dns cache running on cluster nodes.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gce_persistent_disk_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::GcePersistentDiskCsiDriverConfig
Returns Configuration for the Compute Engine Persistent Disk CSI driver.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcp_filestore_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::GcpFilestoreCsiDriverConfig
Returns Configuration for the Filestore CSI driver.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gcs_fuse_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::GcsFuseCsiDriverConfig
Returns Configuration for the Cloud Storage Fuse CSI driver.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#gke_backup_agent_config ⇒ ::Google::Cloud::Container::V1beta1::GkeBackupAgentConfig
Returns Configuration for the Backup for GKE agent addon.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#high_scale_checkpointing_config ⇒ ::Google::Cloud::Container::V1beta1::HighScaleCheckpointingConfig
Returns Configuration for the High Scale Checkpointing add-on.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#horizontal_pod_autoscaling ⇒ ::Google::Cloud::Container::V1beta1::HorizontalPodAutoscaling
Returns Configuration for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#http_load_balancing ⇒ ::Google::Cloud::Container::V1beta1::HttpLoadBalancing
Returns Configuration for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#istio_config ⇒ ::Google::Cloud::Container::V1beta1::IstioConfig
This field is deprecated and may be removed in the next major version update.
Returns Configuration for Istio, an open platform to connect, manage, and secure microservices.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kalm_config ⇒ ::Google::Cloud::Container::V1beta1::KalmConfig
This field is deprecated and may be removed in the next major version update.
Returns Configuration for the KALM addon, which manages the lifecycle of k8s applications.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#kubernetes_dashboard ⇒ ::Google::Cloud::Container::V1beta1::KubernetesDashboard
This field is deprecated and may be removed in the next major version update.
Returns Configuration for the Kubernetes Dashboard. This addon is deprecated, and will be disabled in 1.15. It is recommended to use the Cloud Console to manage and monitor your Kubernetes clusters, workloads and applications. For more information, see: https://cloud.google.com/kubernetes-engine/docs/concepts/dashboards.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#lustre_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::LustreCsiDriverConfig
Returns Configuration for the Lustre CSI driver.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network_policy_config ⇒ ::Google::Cloud::Container::V1beta1::NetworkPolicyConfig
Returns Configuration for NetworkPolicy. This only tracks whether the addon is enabled or not on the Master, it does not track whether network policy is enabled for the nodes.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#node_readiness_config ⇒ ::Google::Cloud::Container::V1beta1::NodeReadinessConfig
Returns Optional. Configuration for NodeReadinessController add-on.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parallelstore_csi_driver_config ⇒ ::Google::Cloud::Container::V1beta1::ParallelstoreCsiDriverConfig
Returns Configuration for the Cloud Storage Parallelstore CSI driver.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pod_snapshot_config ⇒ ::Google::Cloud::Container::V1beta1::PodSnapshotConfig
Returns Configuration for the Pod Snapshot feature.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ray_operator_config ⇒ ::Google::Cloud::Container::V1beta1::RayOperatorConfig
Returns Optional. Configuration for Ray Operator addon.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#slice_controller_config ⇒ ::Google::Cloud::Container::V1beta1::SliceControllerConfig
Returns Optional. Configuration for the slice controller add-on.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#slurm_operator_config ⇒ ::Google::Cloud::Container::V1beta1::SlurmOperatorConfig
Returns Configuration for the Slurm Operator.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#stateful_ha_config ⇒ ::Google::Cloud::Container::V1beta1::StatefulHAConfig
Returns Optional. Configuration for the StatefulHA add-on.
2092 2093 2094 2095 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2092 class AddonsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |