Class: Google::Cloud::Container::V1beta1::AnonymousAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::AnonymousAuthenticationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
AnonymousAuthenticationConfig defines the settings needed to limit endpoints that allow anonymous authentication.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::Container::V1beta1::AnonymousAuthenticationConfig::Mode
Defines the mode of limiting anonymous access in the cluster.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::Container::V1beta1::AnonymousAuthenticationConfig::Mode
Returns Defines the mode of limiting anonymous access in the cluster.
3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 3505 3506 3507 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3491 class AnonymousAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode defines the mode of anonymous authentication # allowed in the cluster. module Mode # Default value not specified. MODE_UNSPECIFIED = 0 # Anonymous authentication is allowed for all endpoints. ENABLED = 1 # Anonymous authentication is allowed for only health check endpoints. LIMITED = 2 end end |