Class: Google::Cloud::Container::V1beta1::BinaryAuthorization

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

Configuration for Binary Authorization.

Defined Under Namespace

Modules: EvaluationMode Classes: PolicyBinding

Instance Attribute Summary collapse

Instance Attribute Details

#enabled::Boolean

Deprecated.

This field is deprecated and may be removed in the next major version update.

Returns This field is deprecated. Leave this unset and instead configure BinaryAuthorization using evaluation_mode. If evaluation_mode is set to anything other than EVALUATION_MODE_UNSPECIFIED, this field is ignored.

Returns:

  • (::Boolean)

    This field is deprecated. Leave this unset and instead configure BinaryAuthorization using evaluation_mode. If evaluation_mode is set to anything other than EVALUATION_MODE_UNSPECIFIED, this field is ignored.



2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2771

class BinaryAuthorization
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Binauthz policy that applies to this cluster.
  # @!attribute [rw] name
  #   @return [::String]
  #     The relative resource name of the binauthz platform policy to evaluate.
  #     GKE platform policies have the following format:
  #     `projects/{project_number}/platforms/gke/policies/{policy_id}`.
  class PolicyBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Binary Authorization mode of operation.
  module EvaluationMode
    # Default value
    EVALUATION_MODE_UNSPECIFIED = 0

    # Disable BinaryAuthorization
    DISABLED = 1

    # Enforce Kubernetes admission requests with BinaryAuthorization using the
    # project's singleton policy. This is equivalent to setting the
    # enabled boolean to true.
    PROJECT_SINGLETON_POLICY_ENFORCE = 2

    # Use Binary Authorization Continuous Validation with the policies
    # specified in policy_bindings.
    POLICY_BINDINGS = 5

    # Use Binary Authorization Continuous Validation with the policies
    # specified in policy_bindings and enforce Kubernetes admission requests
    # with Binary Authorization using the project's singleton policy.
    POLICY_BINDINGS_AND_PROJECT_SINGLETON_POLICY_ENFORCE = 6
  end
end

#evaluation_mode::Google::Cloud::Container::V1beta1::BinaryAuthorization::EvaluationMode

Returns Mode of operation for binauthz policy evaluation. If unspecified, defaults to DISABLED.

Returns:



2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2771

class BinaryAuthorization
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Binauthz policy that applies to this cluster.
  # @!attribute [rw] name
  #   @return [::String]
  #     The relative resource name of the binauthz platform policy to evaluate.
  #     GKE platform policies have the following format:
  #     `projects/{project_number}/platforms/gke/policies/{policy_id}`.
  class PolicyBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Binary Authorization mode of operation.
  module EvaluationMode
    # Default value
    EVALUATION_MODE_UNSPECIFIED = 0

    # Disable BinaryAuthorization
    DISABLED = 1

    # Enforce Kubernetes admission requests with BinaryAuthorization using the
    # project's singleton policy. This is equivalent to setting the
    # enabled boolean to true.
    PROJECT_SINGLETON_POLICY_ENFORCE = 2

    # Use Binary Authorization Continuous Validation with the policies
    # specified in policy_bindings.
    POLICY_BINDINGS = 5

    # Use Binary Authorization Continuous Validation with the policies
    # specified in policy_bindings and enforce Kubernetes admission requests
    # with Binary Authorization using the project's singleton policy.
    POLICY_BINDINGS_AND_PROJECT_SINGLETON_POLICY_ENFORCE = 6
  end
end

#policy_bindings::Array<::Google::Cloud::Container::V1beta1::BinaryAuthorization::PolicyBinding>

Returns Optional. Binauthz policies that apply to this cluster.

Returns:



2771
2772
2773
2774
2775
2776
2777
2778
2779
2780
2781
2782
2783
2784
2785
2786
2787
2788
2789
2790
2791
2792
2793
2794
2795
2796
2797
2798
2799
2800
2801
2802
2803
2804
2805
2806
2807
2808
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2771

class BinaryAuthorization
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Binauthz policy that applies to this cluster.
  # @!attribute [rw] name
  #   @return [::String]
  #     The relative resource name of the binauthz platform policy to evaluate.
  #     GKE platform policies have the following format:
  #     `projects/{project_number}/platforms/gke/policies/{policy_id}`.
  class PolicyBinding
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Binary Authorization mode of operation.
  module EvaluationMode
    # Default value
    EVALUATION_MODE_UNSPECIFIED = 0

    # Disable BinaryAuthorization
    DISABLED = 1

    # Enforce Kubernetes admission requests with BinaryAuthorization using the
    # project's singleton policy. This is equivalent to setting the
    # enabled boolean to true.
    PROJECT_SINGLETON_POLICY_ENFORCE = 2

    # Use Binary Authorization Continuous Validation with the policies
    # specified in policy_bindings.
    POLICY_BINDINGS = 5

    # Use Binary Authorization Continuous Validation with the policies
    # specified in policy_bindings and enforce Kubernetes admission requests
    # with Binary Authorization using the project's singleton policy.
    POLICY_BINDINGS_AND_PROJECT_SINGLETON_POLICY_ENFORCE = 6
  end
end