Class: Google::Cloud::Container::V1beta1::ClusterAutoscaling

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

ClusterAutoscaling contains global, per-cluster information required by Cluster Autoscaler to automatically adjust the size of the cluster and create/delete node pools based on the current needs.

Defined Under Namespace

Modules: AutopilotGeneralProfile, AutoscalingProfile

Instance Attribute Summary collapse

Instance Attribute Details

#autopilot_general_profile::Google::Cloud::Container::V1beta1::ClusterAutoscaling::AutopilotGeneralProfile

Returns Autopilot general profile for the cluster, which defines the configuration for the cluster.

Returns:



6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6331

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1

    # Use default configuration.
    NONE = 2
  end
end

#autoprovisioning_locations::Array<::String>

Returns The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP.

Returns:

  • (::Array<::String>)

    The list of Google Compute Engine zones in which the NodePool's nodes can be created by NAP.



6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6331

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1

    # Use default configuration.
    NONE = 2
  end
end

#autoprovisioning_node_pool_defaults::Google::Cloud::Container::V1beta1::AutoprovisioningNodePoolDefaults

Returns AutoprovisioningNodePoolDefaults contains defaults for a node pool created by NAP.

Returns:



6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6331

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1

    # Use default configuration.
    NONE = 2
  end
end

#autoscaling_profile::Google::Cloud::Container::V1beta1::ClusterAutoscaling::AutoscalingProfile

Returns Defines autoscaling behaviour.



6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6331

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1

    # Use default configuration.
    NONE = 2
  end
end

#default_compute_class_config::Google::Cloud::Container::V1beta1::DefaultComputeClassConfig

Returns Default compute class is a configuration for default compute class.

Returns:



6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6331

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1

    # Use default configuration.
    NONE = 2
  end
end

#enable_node_autoprovisioning::Boolean

Returns Enables automatic node pool creation and deletion.

Returns:

  • (::Boolean)

    Enables automatic node pool creation and deletion.



6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6331

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1

    # Use default configuration.
    NONE = 2
  end
end

#resource_limits::Array<::Google::Cloud::Container::V1beta1::ResourceLimit>

Returns Contains global constraints regarding minimum and maximum amount of resources in the cluster.

Returns:



6331
6332
6333
6334
6335
6336
6337
6338
6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6331

class ClusterAutoscaling
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Defines possible options for autoscaling_profile field.
  module AutoscalingProfile
    # No change to autoscaling configuration.
    PROFILE_UNSPECIFIED = 0

    # Prioritize optimizing utilization of resources.
    OPTIMIZE_UTILIZATION = 1

    # Use default (balanced) autoscaling configuration.
    BALANCED = 2
  end

  # Defines possible options for Autopilot general profile.
  module AutopilotGeneralProfile
    # Use default configuration.
    AUTOPILOT_GENERAL_PROFILE_UNSPECIFIED = 0

    # Avoid extra IP consumption.
    NO_PERFORMANCE = 1

    # Use default configuration.
    NONE = 2
  end
end