Class: Google::Cloud::Container::V1beta1::ClusterUpgradeInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::ClusterUpgradeInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
ClusterUpgradeInfo contains the upgrade information of a cluster.
Defined Under Namespace
Modules: AutoUpgradePausedReason, AutoUpgradeStatus
Instance Attribute Summary collapse
-
#auto_upgrade_status ⇒ ::Array<::Google::Cloud::Container::V1beta1::ClusterUpgradeInfo::AutoUpgradeStatus>
The auto upgrade status.
-
#end_of_extended_support_timestamp ⇒ ::String
The cluster's current minor version's end of extended support timestamp.
-
#end_of_standard_support_timestamp ⇒ ::String
The cluster's current minor version's end of standard support timestamp.
-
#minor_target_version ⇒ ::String
Minor_target_version indicates the target version for minor upgrade.
-
#patch_target_version ⇒ ::String
Patch_target_version indicates the target version for patch upgrade.
-
#paused_reason ⇒ ::Array<::Google::Cloud::Container::V1beta1::ClusterUpgradeInfo::AutoUpgradePausedReason>
The auto upgrade paused reason.
-
#rollback_safe_upgrade_status ⇒ ::Google::Cloud::Container::V1beta1::RollbackSafeUpgradeStatus
The cluster's rollback-safe upgrade status.
-
#upgrade_details ⇒ ::Array<::Google::Cloud::Container::V1beta1::UpgradeDetails>
The list of past auto upgrades.
Instance Attribute Details
#auto_upgrade_status ⇒ ::Array<::Google::Cloud::Container::V1beta1::ClusterUpgradeInfo::AutoUpgradeStatus>
Returns The auto upgrade status.
8830 8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8830 class ClusterUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 4 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 5 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 5 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 6 # CLUSTER_DISRUPTION_BUDGET indicates the cluster is outside the cluster # disruption budget. CLUSTER_DISRUPTION_BUDGET = 4 # CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE indicates the cluster is outside # the cluster disruption budget for minor version upgrade. CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE = 7 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 8 end end |
#end_of_extended_support_timestamp ⇒ ::String
Returns The cluster's current minor version's end of extended support timestamp.
8830 8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8830 class ClusterUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 4 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 5 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 5 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 6 # CLUSTER_DISRUPTION_BUDGET indicates the cluster is outside the cluster # disruption budget. CLUSTER_DISRUPTION_BUDGET = 4 # CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE indicates the cluster is outside # the cluster disruption budget for minor version upgrade. CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE = 7 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 8 end end |
#end_of_standard_support_timestamp ⇒ ::String
Returns The cluster's current minor version's end of standard support timestamp.
8830 8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8830 class ClusterUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 4 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 5 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 5 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 6 # CLUSTER_DISRUPTION_BUDGET indicates the cluster is outside the cluster # disruption budget. CLUSTER_DISRUPTION_BUDGET = 4 # CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE indicates the cluster is outside # the cluster disruption budget for minor version upgrade. CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE = 7 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 8 end end |
#minor_target_version ⇒ ::String
Returns minor_target_version indicates the target version for minor upgrade.
8830 8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8830 class ClusterUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 4 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 5 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 5 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 6 # CLUSTER_DISRUPTION_BUDGET indicates the cluster is outside the cluster # disruption budget. CLUSTER_DISRUPTION_BUDGET = 4 # CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE indicates the cluster is outside # the cluster disruption budget for minor version upgrade. CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE = 7 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 8 end end |
#patch_target_version ⇒ ::String
Returns patch_target_version indicates the target version for patch upgrade.
8830 8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8830 class ClusterUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 4 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 5 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 5 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 6 # CLUSTER_DISRUPTION_BUDGET indicates the cluster is outside the cluster # disruption budget. CLUSTER_DISRUPTION_BUDGET = 4 # CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE indicates the cluster is outside # the cluster disruption budget for minor version upgrade. CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE = 7 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 8 end end |
#paused_reason ⇒ ::Array<::Google::Cloud::Container::V1beta1::ClusterUpgradeInfo::AutoUpgradePausedReason>
Returns The auto upgrade paused reason.
8830 8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8830 class ClusterUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 4 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 5 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 5 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 6 # CLUSTER_DISRUPTION_BUDGET indicates the cluster is outside the cluster # disruption budget. CLUSTER_DISRUPTION_BUDGET = 4 # CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE indicates the cluster is outside # the cluster disruption budget for minor version upgrade. CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE = 7 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 8 end end |
#rollback_safe_upgrade_status ⇒ ::Google::Cloud::Container::V1beta1::RollbackSafeUpgradeStatus
Returns The cluster's rollback-safe upgrade status.
8830 8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8830 class ClusterUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 4 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 5 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 5 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 6 # CLUSTER_DISRUPTION_BUDGET indicates the cluster is outside the cluster # disruption budget. CLUSTER_DISRUPTION_BUDGET = 4 # CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE indicates the cluster is outside # the cluster disruption budget for minor version upgrade. CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE = 7 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 8 end end |
#upgrade_details ⇒ ::Array<::Google::Cloud::Container::V1beta1::UpgradeDetails>
Returns The list of past auto upgrades.
8830 8831 8832 8833 8834 8835 8836 8837 8838 8839 8840 8841 8842 8843 8844 8845 8846 8847 8848 8849 8850 8851 8852 8853 8854 8855 8856 8857 8858 8859 8860 8861 8862 8863 8864 8865 8866 8867 8868 8869 8870 8871 8872 8873 8874 8875 8876 8877 8878 8879 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8830 class ClusterUpgradeInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # AutoUpgradeStatus indicates the status of auto upgrade. module AutoUpgradeStatus # UNKNOWN indicates an unknown status. UNKNOWN = 0 # ACTIVE indicates an active status. ACTIVE = 1 # MINOR_UPGRADE_PAUSED indicates the minor version upgrade is # paused. MINOR_UPGRADE_PAUSED = 4 # UPGRADE_PAUSED indicates the upgrade is paused. UPGRADE_PAUSED = 5 end # AutoUpgradePausedReason indicates the reason for auto upgrade paused # status. module AutoUpgradePausedReason # AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED indicates an unspecified reason. AUTO_UPGRADE_PAUSED_REASON_UNSPECIFIED = 0 # MAINTENANCE_WINDOW indicates the cluster is outside customer maintenance # window. MAINTENANCE_WINDOW = 1 # MAINTENANCE_EXCLUSION_NO_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_UPGRADES. MAINTENANCE_EXCLUSION_NO_UPGRADES = 5 # MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES indicates the cluster is in a # maintenance exclusion with scope NO_MINOR_UPGRADES. MAINTENANCE_EXCLUSION_NO_MINOR_UPGRADES = 6 # CLUSTER_DISRUPTION_BUDGET indicates the cluster is outside the cluster # disruption budget. CLUSTER_DISRUPTION_BUDGET = 4 # CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE indicates the cluster is outside # the cluster disruption budget for minor version upgrade. CLUSTER_DISRUPTION_BUDGET_MINOR_UPGRADE = 7 # SYSTEM_CONFIG indicates the cluster upgrade is paused by system config. SYSTEM_CONFIG = 8 end end |