Class: Google::Cloud::Container::V1beta1::CompatibilityStatus
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::CompatibilityStatus
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
CompatibilityStatus is the status regarding the control plane's compatibility.
Instance Attribute Summary collapse
-
#downgradable_version ⇒ ::String
readonly
Output only.
-
#emulated_version_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#downgradable_version ⇒ ::String (readonly)
Returns Output only. The GKE version that the cluster can be safely downgraded to if the cluster is emulating the previous minor version. It is usually the cluster's previous version before a minor version upgrade.
7829 7830 7831 7832 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7829 class CompatibilityStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#emulated_version_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. Last time the control plane became available after a minor version binary upgrade with emulated version set. It indicates the last time the cluster entered the rollback safe mode.
7829 7830 7831 7832 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7829 class CompatibilityStatus include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |