Class: Google::Cloud::Container::V1beta1::ConfidentialNodes
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::ConfidentialNodes
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs.
Defined Under Namespace
Modules: ConfidentialInstanceType
Instance Attribute Summary collapse
-
#confidential_instance_type ⇒ ::Google::Cloud::Container::V1beta1::ConfidentialNodes::ConfidentialInstanceType
Defines the type of technology used by the confidential node.
-
#enabled ⇒ ::Boolean
Whether Confidential Nodes feature is enabled.
Instance Attribute Details
#confidential_instance_type ⇒ ::Google::Cloud::Container::V1beta1::ConfidentialNodes::ConfidentialInstanceType
Returns Defines the type of technology used by the confidential node.
8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 8025 8026 8027 8028 8029 8030 8031 8032 8033 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8015 class ConfidentialNodes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of technology used by the confidential node. module ConfidentialInstanceType # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0 # AMD Secure Encrypted Virtualization. SEV = 1 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 2 # Intel Trust Domain eXtension. TDX = 3 end end |
#enabled ⇒ ::Boolean
Returns Whether Confidential Nodes feature is enabled.
8015 8016 8017 8018 8019 8020 8021 8022 8023 8024 8025 8026 8027 8028 8029 8030 8031 8032 8033 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8015 class ConfidentialNodes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of technology used by the confidential node. module ConfidentialInstanceType # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0 # AMD Secure Encrypted Virtualization. SEV = 1 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 2 # Intel Trust Domain eXtension. TDX = 3 end end |