Class: Google::Cloud::Container::V1beta1::ControlPlaneEgress

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

ControlPlaneEgress defines the settings needed to enable control plane egress control.

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Attribute Details

#mode::Google::Cloud::Container::V1beta1::ControlPlaneEgress::Mode

Returns Defines the mode of control plane egress.

Returns:



3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
3394
3395
3396
3397
3398
3399
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3384

class ControlPlaneEgress
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines the mode of control plane egress.
  module Mode
    # Default value not specified.
    MODE_UNSPECIFIED = 0

    # Control plane has public IP and no restriction on egress.
    VIA_CONTROL_PLANE = 1

    # No public IP on control plane and only internal allowlisted egress.
    NONE = 2
  end
end