Class: Google::Cloud::Container::V1beta1::CustomImageConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::CustomImageConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
CustomImageConfig contains the information r
Instance Attribute Summary collapse
-
#image ⇒ ::String
The name of the image to use for this node.
-
#image_project ⇒ ::String
The project containing the image to use for this node.
Instance Attribute Details
#image ⇒ ::String
Returns The name of the image to use for this node.
1424 1425 1426 1427 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1424 class CustomImageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#image_project ⇒ ::String
Returns The project containing the image to use for this node.
1424 1425 1426 1427 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1424 class CustomImageConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |