Class: Google::Cloud::Container::V1beta1::DisruptionBudget
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::DisruptionBudget
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
DisruptionBudget defines the upgrade disruption budget for the cluster control plane.
Instance Attribute Summary collapse
-
#last_disruption_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#last_minor_version_disruption_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#minor_version_disruption_interval ⇒ ::Google::Protobuf::Duration
Optional.
-
#patch_version_disruption_interval ⇒ ::Google::Protobuf::Duration
Optional.
Instance Attribute Details
#last_disruption_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last time a disruption was performed on the control plane.
5934 5935 5936 5937 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5934 class DisruptionBudget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#last_minor_version_disruption_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. The last time a minor version upgrade was performed on the control plane.
5934 5935 5936 5937 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5934 class DisruptionBudget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#minor_version_disruption_interval ⇒ ::Google::Protobuf::Duration
Returns Optional. The minimum duration between two minor version upgrades of the control plane.
5934 5935 5936 5937 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5934 class DisruptionBudget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#patch_version_disruption_interval ⇒ ::Google::Protobuf::Duration
Returns Optional. The minimum duration between two patch version upgrades of the control plane.
5934 5935 5936 5937 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5934 class DisruptionBudget include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |