Class: Google::Cloud::Container::V1beta1::GPUDirectConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::GPUDirectConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
GPUDirectConfig specifies the GPU direct strategy on the node pool.
Defined Under Namespace
Modules: GPUDirectStrategy
Instance Attribute Summary collapse
-
#gpu_direct_strategy ⇒ ::Google::Cloud::Container::V1beta1::GPUDirectConfig::GPUDirectStrategy
The type of GPU direct strategy to enable on the node pool.
Instance Attribute Details
#gpu_direct_strategy ⇒ ::Google::Cloud::Container::V1beta1::GPUDirectConfig::GPUDirectStrategy
Returns The type of GPU direct strategy to enable on the node pool.
7523 7524 7525 7526 7527 7528 7529 7530 7531 7532 7533 7534 7535 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7523 class GPUDirectConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Option for GPU direct Strategies module GPUDirectStrategy # Default value. No GPU Direct strategy is enabled on the node. GPU_DIRECT_STRATEGY_UNSPECIFIED = 0 # GPUDirect-RDMA on A3 Ultra, and A4 machine types RDMA = 2 end end |