Class: Google::Cloud::Container::V1beta1::LegacyAbac
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::LegacyAbac
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Configuration for the legacy Attribute Based Access Control authorization mode.
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Whether the ABAC authorizer is enabled for this cluster.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Whether the ABAC authorizer is enabled for this cluster. When enabled, identities in the system, including service accounts, nodes, and controllers, will have statically granted permissions beyond those provided by the RBAC configuration or IAM.
2481 2482 2483 2484 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2481 class LegacyAbac include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |