Class: Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Configuration for swap memory on a node pool.
Defined Under Namespace
Classes: BootDiskProfile, DedicatedLocalSsdProfile, EncryptionConfig, EphemeralLocalSsdProfile
Instance Attribute Summary collapse
-
#boot_disk_profile ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig::BootDiskProfile
Swap on the node's boot disk.
-
#dedicated_local_ssd_profile ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig::DedicatedLocalSsdProfile
Provisions a new, separate local NVMe SSD exclusively for swap.
-
#enabled ⇒ ::Boolean
Optional.
-
#encryption_config ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig::EncryptionConfig
Optional.
-
#ephemeral_local_ssd_profile ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig::EphemeralLocalSsdProfile
Swap on the local SSD shared with pod ephemeral storage.
Instance Attribute Details
#boot_disk_profile ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig::BootDiskProfile
Returns Swap on the node's boot disk.
Note: The following fields are mutually exclusive: boot_disk_profile, ephemeral_local_ssd_profile, dedicated_local_ssd_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 220 class SwapConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines encryption settings for the swap space. # @!attribute [rw] disabled # @return [::Boolean] # Optional. If true, swap space will not be encrypted. # Defaults to false (encrypted). class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the node's boot disk. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the boot disk # size. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BootDiskProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the local SSD shared with pod ephemeral storage. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the ephemeral # local SSD capacity. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class EphemeralLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisions a new, separate local NVMe SSD exclusively for swap. # @!attribute [rw] disk_count # @return [::Integer] # The number of physical local NVMe SSD disks to attach. class DedicatedLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#dedicated_local_ssd_profile ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig::DedicatedLocalSsdProfile
Returns Provisions a new, separate local NVMe SSD exclusively for swap.
Note: The following fields are mutually exclusive: dedicated_local_ssd_profile, boot_disk_profile, ephemeral_local_ssd_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 220 class SwapConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines encryption settings for the swap space. # @!attribute [rw] disabled # @return [::Boolean] # Optional. If true, swap space will not be encrypted. # Defaults to false (encrypted). class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the node's boot disk. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the boot disk # size. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BootDiskProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the local SSD shared with pod ephemeral storage. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the ephemeral # local SSD capacity. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class EphemeralLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisions a new, separate local NVMe SSD exclusively for swap. # @!attribute [rw] disk_count # @return [::Integer] # The number of physical local NVMe SSD disks to attach. class DedicatedLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enabled ⇒ ::Boolean
Returns Optional. Enables or disables swap for the node pool.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 220 class SwapConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines encryption settings for the swap space. # @!attribute [rw] disabled # @return [::Boolean] # Optional. If true, swap space will not be encrypted. # Defaults to false (encrypted). class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the node's boot disk. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the boot disk # size. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BootDiskProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the local SSD shared with pod ephemeral storage. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the ephemeral # local SSD capacity. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class EphemeralLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisions a new, separate local NVMe SSD exclusively for swap. # @!attribute [rw] disk_count # @return [::Integer] # The number of physical local NVMe SSD disks to attach. class DedicatedLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#encryption_config ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig::EncryptionConfig
Returns Optional. If omitted, swap space is encrypted by default.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 220 class SwapConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines encryption settings for the swap space. # @!attribute [rw] disabled # @return [::Boolean] # Optional. If true, swap space will not be encrypted. # Defaults to false (encrypted). class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the node's boot disk. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the boot disk # size. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BootDiskProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the local SSD shared with pod ephemeral storage. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the ephemeral # local SSD capacity. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class EphemeralLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisions a new, separate local NVMe SSD exclusively for swap. # @!attribute [rw] disk_count # @return [::Integer] # The number of physical local NVMe SSD disks to attach. class DedicatedLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ephemeral_local_ssd_profile ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::SwapConfig::EphemeralLocalSsdProfile
Returns Swap on the local SSD shared with pod ephemeral storage.
Note: The following fields are mutually exclusive: ephemeral_local_ssd_profile, boot_disk_profile, dedicated_local_ssd_profile. If a field in that set is populated, all other fields in the set will automatically be cleared.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 220 class SwapConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Defines encryption settings for the swap space. # @!attribute [rw] disabled # @return [::Boolean] # Optional. If true, swap space will not be encrypted. # Defaults to false (encrypted). class EncryptionConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the node's boot disk. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the boot disk # size. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class BootDiskProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Swap on the local SSD shared with pod ephemeral storage. # @!attribute [rw] swap_size_gib # @return [::Integer] # Specifies the size of the swap space in gibibytes (GiB). # # Note: The following fields are mutually exclusive: `swap_size_gib`, `swap_size_percent`. If a field in that set is populated, all other fields in the set will automatically be cleared. # @!attribute [rw] swap_size_percent # @return [::Integer] # Specifies the size of the swap space as a percentage of the ephemeral # local SSD capacity. # # Note: The following fields are mutually exclusive: `swap_size_percent`, `swap_size_gib`. If a field in that set is populated, all other fields in the set will automatically be cleared. class EphemeralLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Provisions a new, separate local NVMe SSD exclusively for swap. # @!attribute [rw] disk_count # @return [::Integer] # The number of physical local NVMe SSD disks to attach. class DedicatedLocalSsdProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |