Class: Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

Represents the Maintenance exclusion option.

Defined Under Namespace

Modules: EndTimeBehavior, Scope

Instance Attribute Summary collapse

Instance Attribute Details

#end_time_behavior::Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions::EndTimeBehavior

Returns EndTimeBehavior specifies the behavior of the exclusion end time.

Returns:



6040
6041
6042
6043
6044
6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
6069
6070
6071
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6040

class MaintenanceExclusionOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Scope of exclusion.
  module Scope
    # NO_UPGRADES excludes all upgrades, including patch upgrades and minor
    # upgrades across control planes and nodes. This is the default exclusion
    # behavior.
    NO_UPGRADES = 0

    # NO_MINOR_UPGRADES excludes all minor upgrades for the cluster, only
    # patches are allowed.
    NO_MINOR_UPGRADES = 1

    # NO_MINOR_OR_NODE_UPGRADES excludes all minor upgrades for the cluster,
    # and also exclude all node pool upgrades. Only control
    # plane patches are allowed.
    NO_MINOR_OR_NODE_UPGRADES = 2
  end

  # EndTimeBehavior specifies the behavior of the exclusion end time.
  module EndTimeBehavior
    # END_TIME_BEHAVIOR_UNSPECIFIED is the default behavior, which is fixed
    # end time.
    END_TIME_BEHAVIOR_UNSPECIFIED = 0

    # UNTIL_END_OF_SUPPORT means the exclusion will be in effect until the end
    # of the support of the cluster's current version.
    UNTIL_END_OF_SUPPORT = 1
  end
end

#scope::Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions::Scope

Returns Scope specifies the upgrade scope which upgrades are blocked by the exclusion.

Returns:



6040
6041
6042
6043
6044
6045
6046
6047
6048
6049
6050
6051
6052
6053
6054
6055
6056
6057
6058
6059
6060
6061
6062
6063
6064
6065
6066
6067
6068
6069
6070
6071
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6040

class MaintenanceExclusionOptions
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Scope of exclusion.
  module Scope
    # NO_UPGRADES excludes all upgrades, including patch upgrades and minor
    # upgrades across control planes and nodes. This is the default exclusion
    # behavior.
    NO_UPGRADES = 0

    # NO_MINOR_UPGRADES excludes all minor upgrades for the cluster, only
    # patches are allowed.
    NO_MINOR_UPGRADES = 1

    # NO_MINOR_OR_NODE_UPGRADES excludes all minor upgrades for the cluster,
    # and also exclude all node pool upgrades. Only control
    # plane patches are allowed.
    NO_MINOR_OR_NODE_UPGRADES = 2
  end

  # EndTimeBehavior specifies the behavior of the exclusion end time.
  module EndTimeBehavior
    # END_TIME_BEHAVIOR_UNSPECIFIED is the default behavior, which is fixed
    # end time.
    END_TIME_BEHAVIOR_UNSPECIFIED = 0

    # UNTIL_END_OF_SUPPORT means the exclusion will be in effect until the end
    # of the support of the cluster's current version.
    UNTIL_END_OF_SUPPORT = 1
  end
end