Class: Google::Cloud::Container::V1beta1::MaintenancePolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::MaintenancePolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
MaintenancePolicy defines the maintenance policy to be used for the cluster.
Instance Attribute Summary collapse
-
#disruption_budget ⇒ ::Google::Cloud::Container::V1beta1::DisruptionBudget
Optional.
-
#resource_version ⇒ ::String
A hash identifying the version of this policy, so that updates to fields of the policy won't accidentally undo intermediate changes (and so that users of the API unaware of some fields won't accidentally remove other fields).
-
#window ⇒ ::Google::Cloud::Container::V1beta1::MaintenanceWindow
Specifies the maintenance window in which maintenance may be performed.
Instance Attribute Details
#disruption_budget ⇒ ::Google::Cloud::Container::V1beta1::DisruptionBudget
Returns Optional. The upgrade disruption budget for the cluster control plane.
5912 5913 5914 5915 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5912 class MaintenancePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#resource_version ⇒ ::String
Returns A hash identifying the version of this policy, so that updates to fields of
the policy won't accidentally undo intermediate changes (and so that users
of the API unaware of some fields won't accidentally remove other fields).
Make a get() request to the cluster to get the current
resource version and include it with requests to set the policy.
5912 5913 5914 5915 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5912 class MaintenancePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#window ⇒ ::Google::Cloud::Container::V1beta1::MaintenanceWindow
Returns Specifies the maintenance window in which maintenance may be performed.
5912 5913 5914 5915 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5912 class MaintenancePolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |