Class: Google::Cloud::Container::V1beta1::MasterAuthorizedNetworksConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

Configuration options for the master authorized networks feature. Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs.

Defined Under Namespace

Classes: CidrBlock

Instance Attribute Summary collapse

Instance Attribute Details

#cidr_blocks::Array<::Google::Cloud::Container::V1beta1::MasterAuthorizedNetworksConfig::CidrBlock>

Returns cidr_blocks define up to 10 external networks that could access Kubernetes master through HTTPS.

Returns:



2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2477

class MasterAuthorizedNetworksConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CidrBlock contains an optional name and one CIDR block.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     display_name is an optional field for users to identify CIDR blocks.
  # @!attribute [rw] cidr_block
  #   @return [::String]
  #     cidr_block must be specified in CIDR notation.
  class CidrBlock
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#enabled::Boolean

Returns Whether or not master authorized networks is enabled.

Returns:

  • (::Boolean)

    Whether or not master authorized networks is enabled.



2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2477

class MasterAuthorizedNetworksConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CidrBlock contains an optional name and one CIDR block.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     display_name is an optional field for users to identify CIDR blocks.
  # @!attribute [rw] cidr_block
  #   @return [::String]
  #     cidr_block must be specified in CIDR notation.
  class CidrBlock
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#gcp_public_cidrs_access_enabled::Boolean

Returns Whether master is accessible via Google Compute Engine Public IP addresses.

Returns:

  • (::Boolean)

    Whether master is accessible via Google Compute Engine Public IP addresses.



2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2477

class MasterAuthorizedNetworksConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CidrBlock contains an optional name and one CIDR block.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     display_name is an optional field for users to identify CIDR blocks.
  # @!attribute [rw] cidr_block
  #   @return [::String]
  #     cidr_block must be specified in CIDR notation.
  class CidrBlock
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#private_endpoint_enforcement_enabled::Boolean

Returns Whether master authorized networks is enforced on private endpoint or not.

Returns:

  • (::Boolean)

    Whether master authorized networks is enforced on private endpoint or not.



2477
2478
2479
2480
2481
2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2477

class MasterAuthorizedNetworksConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # CidrBlock contains an optional name and one CIDR block.
  # @!attribute [rw] display_name
  #   @return [::String]
  #     display_name is an optional field for users to identify CIDR blocks.
  # @!attribute [rw] cidr_block
  #   @return [::String]
  #     cidr_block must be specified in CIDR notation.
  class CidrBlock
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end