Class: Google::Cloud::Container::V1beta1::NetworkTierConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

NetworkTierConfig contains network tier information.

Defined Under Namespace

Modules: NetworkTier

Instance Attribute Summary collapse

Instance Attribute Details

#network_tier::Google::Cloud::Container::V1beta1::NetworkTierConfig::NetworkTier

Returns Network tier configuration.

Returns:



9085
9086
9087
9088
9089
9090
9091
9092
9093
9094
9095
9096
9097
9098
9099
9100
9101
9102
9103
9104
9105
9106
9107
9108
9109
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 9085

class NetworkTierConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Network tier configuration.
  module NetworkTier
    # By default, use project-level configuration. When unspecified, the
    # behavior defaults to NETWORK_TIER_DEFAULT. For cluster updates, this
    # implies no action (no-op).
    NETWORK_TIER_UNSPECIFIED = 0

    # Default network tier. Use project-level configuration. User can specify
    # this value, meaning they want to keep the same behaviour as before
    # cluster level network tier configuration is introduced. This field
    # ensures backward compatibility for the network tier of cluster resources,
    # such as node pools and load balancers, for their external IP addresses.
    NETWORK_TIER_DEFAULT = 1

    # Premium network tier.
    NETWORK_TIER_PREMIUM = 2

    # Standard network tier.
    NETWORK_TIER_STANDARD = 3
  end
end