Class: Google::Cloud::Container::V1beta1::NodeNetworkConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::NodeNetworkConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Parameters for node pool-level network config.
Defined Under Namespace
Classes: NetworkPerformanceConfig
Instance Attribute Summary collapse
-
#accelerator_network_profile ⇒ ::String
Immutable.
-
#additional_node_network_configs ⇒ ::Array<::Google::Cloud::Container::V1beta1::AdditionalNodeNetworkConfig>
We specify the additional node networks for this node pool using this list.
-
#additional_pod_network_configs ⇒ ::Array<::Google::Cloud::Container::V1beta1::AdditionalPodNetworkConfig>
We specify the additional pod networks for this node pool using this list.
-
#create_pod_range ⇒ ::Boolean
Input only.
-
#enable_private_nodes ⇒ ::Boolean
Whether nodes have internal IP addresses only.
-
#network_performance_config ⇒ ::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig
Network bandwidth tier configuration.
-
#network_tier_config ⇒ ::Google::Cloud::Container::V1beta1::NetworkTierConfig
readonly
Output only.
-
#pod_cidr_overprovision_config ⇒ ::Google::Cloud::Container::V1beta1::PodCIDROverprovisionConfig
[PRIVATE FIELD] Pod CIDR size overprovisioning config for the node pool.
-
#pod_ipv4_cidr_block ⇒ ::String
The IP address range for pod IPs in this node pool.
-
#pod_ipv4_range_utilization ⇒ ::Float
readonly
Output only.
-
#pod_range ⇒ ::String
The ID of the secondary range for pod IPs.
-
#subnetwork ⇒ ::String
Optional.
Instance Attribute Details
#accelerator_network_profile ⇒ ::String
Returns Immutable. The accelerator network profile for the node pool. For now the only valid value is "auto". If specified, the network configuration of the nodes in this node pool will be managed by this profile for the supported machine types, zone, etc.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#additional_node_network_configs ⇒ ::Array<::Google::Cloud::Container::V1beta1::AdditionalNodeNetworkConfig>
Returns We specify the additional node networks for this node pool using this list. Each node network corresponds to an additional interface.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#additional_pod_network_configs ⇒ ::Array<::Google::Cloud::Container::V1beta1::AdditionalPodNetworkConfig>
Returns We specify the additional pod networks for this node pool using this list. Each pod network corresponds to an additional alias IP range for the node.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#create_pod_range ⇒ ::Boolean
Returns Input only. Whether to create a new range for pod IPs in this node pool.
Defaults are provided for pod_range and pod_ipv4_cidr_block if they
are not specified.
If neither create_pod_range or pod_range are specified, the
cluster-level default (ip_allocation_policy.cluster_ipv4_cidr_block) is
used.
Only applicable if ip_allocation_policy.use_ip_aliases is true.
This field cannot be changed after the node pool has been created.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#enable_private_nodes ⇒ ::Boolean
Returns Whether nodes have internal IP addresses only. If enable_private_nodes is not specified, then the value is derived from [Cluster.NetworkConfig.default_enable_private_nodes][].
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#network_performance_config ⇒ ::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig
Returns Network bandwidth tier configuration.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#network_tier_config ⇒ ::Google::Cloud::Container::V1beta1::NetworkTierConfig (readonly)
Returns Output only. The network tier configuration for the node pool inherits from the cluster-level configuration and remains immutable throughout the node pool's lifecycle, including during upgrades.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#pod_cidr_overprovision_config ⇒ ::Google::Cloud::Container::V1beta1::PodCIDROverprovisionConfig
Returns [PRIVATE FIELD] Pod CIDR size overprovisioning config for the node pool.
Pod CIDR size per node depends on max_pods_per_node. By default, the value of max_pods_per_node is rounded off to next power of 2 and we then double that to get the size of pod CIDR block per node. Example: max_pods_per_node of 30 would result in 64 IPs (/26).
This config can disable the doubling of IPs (we still round off to next power of 2) Example: max_pods_per_node of 30 will result in 32 IPs (/27) when overprovisioning is disabled.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#pod_ipv4_cidr_block ⇒ ::String
Returns The IP address range for pod IPs in this node pool.
Only applicable if create_pod_range is true.
Set to blank to have a range chosen with the default size.
Set to /netmask (e.g. /14) to have a range chosen with a specific
netmask.
Set to a
CIDR
notation (e.g. 10.96.0.0/14) to pick a specific range to use.
Only applicable if ip_allocation_policy.use_ip_aliases is true.
This field cannot be changed after the node pool has been created.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#pod_ipv4_range_utilization ⇒ ::Float (readonly)
Returns Output only. The utilization of the IPv4 range for the pod. The ratio is Usage/[Total number of IPs in the secondary range], Usage=numNodes*numZones*podIPsPerNode.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#pod_range ⇒ ::String
Returns The ID of the secondary range for pod IPs.
If create_pod_range is true, this ID is used for the new range.
If create_pod_range is false, uses an existing secondary range with this
ID.
Only applicable if ip_allocation_policy.use_ip_aliases is true.
This field cannot be changed after the node pool has been created.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |
#subnetwork ⇒ ::String
Returns Optional. The subnetwork name/path for the node pool. Format: projects/{project}/regions/{region}/subnetworks/{subnetwork} If the cluster is associated with multiple subnetworks, the subnetwork can be either:
- A user supplied subnetwork name during node pool creation (e.g.,
my-subnet). The name must be between 1 and 63 characters long, start with a letter, contain only letters, numbers, and hyphens, and end with a letter or a number. - A full subnetwork path during node pool creation, such as
projects/gke-project/regions/us-central1/subnetworks/my-subnet - A subnetwork path picked based on the IP utilization during node pool creation and is immutable.
1330 1331 1332 1333 1334 1335 1336 1337 1338 1339 1340 1341 1342 1343 1344 1345 1346 1347 1348 1349 1350 1351 1352 1353 1354 1355 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1330 class NodeNetworkConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Configuration of all network bandwidth tiers # @!attribute [rw] total_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the total network bandwidth tier for the NodePool. # @!attribute [rw] external_ip_egress_bandwidth_tier # @return [::Google::Cloud::Container::V1beta1::NodeNetworkConfig::NetworkPerformanceConfig::Tier] # Specifies the network bandwidth tier for the NodePool for traffic to # external/public IP addresses. class NetworkPerformanceConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Node network tier module Tier # Default value TIER_UNSPECIFIED = 0 # Higher bandwidth, actual values based on VM size. TIER_1 = 1 end end end |