Class: Google::Cloud::Container::V1beta1::NodePool::NodeDrainConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::NodePool::NodeDrainConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
NodeDrainConfig contains the node drain related configurations for this node pool.
Instance Attribute Summary collapse
-
#grace_termination_duration ⇒ ::Google::Protobuf::Duration
The duration of the grace termination period for node drain.
-
#pdb_timeout_duration ⇒ ::Google::Protobuf::Duration
The duration of the PDB timeout period for node drain.
-
#respect_pdb_during_node_pool_deletion ⇒ ::Boolean
Whether to respect PDB during node pool deletion.
Instance Attribute Details
#grace_termination_duration ⇒ ::Google::Protobuf::Duration
Returns The duration of the grace termination period for node drain.
5801 5802 5803 5804 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5801 class NodeDrainConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#pdb_timeout_duration ⇒ ::Google::Protobuf::Duration
Returns The duration of the PDB timeout period for node drain.
5801 5802 5803 5804 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5801 class NodeDrainConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#respect_pdb_during_node_pool_deletion ⇒ ::Boolean
Returns Whether to respect PDB during node pool deletion.
5801 5802 5803 5804 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5801 class NodeDrainConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |