Class: Google::Cloud::Container::V1beta1::NodePool::PlacementPolicy
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::NodePool::PlacementPolicy
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
PlacementPolicy defines the placement policy used by the node pool.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#policy_name ⇒ ::String
If set, refers to the name of a custom resource policy supplied by the user.
-
#tpu_topology ⇒ ::String
TPU placement topology for pod slice node pool.
-
#type ⇒ ::Google::Cloud::Container::V1beta1::NodePool::PlacementPolicy::Type
The type of placement.
Instance Attribute Details
#policy_name ⇒ ::String
Returns If set, refers to the name of a custom resource policy supplied by the user. The resource policy must be in the same project and region as the node pool. If not found, InvalidArgument error is returned.
5763 5764 5765 5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5763 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |
#tpu_topology ⇒ ::String
Returns TPU placement topology for pod slice node pool. https://cloud.google.com/tpu/docs/types-topologies#tpu_topologies.
5763 5764 5765 5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5763 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |
#type ⇒ ::Google::Cloud::Container::V1beta1::NodePool::PlacementPolicy::Type
Returns The type of placement.
5763 5764 5765 5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5763 class PlacementPolicy include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Type defines the type of placement policy. module Type # TYPE_UNSPECIFIED specifies no requirements on nodes # placement. TYPE_UNSPECIFIED = 0 # COMPACT specifies node placement in the same availability domain to # ensure low communication latency. COMPACT = 1 end end |