Class: Google::Cloud::Container::V1beta1::NodePool::UpdateInfo
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::NodePool::UpdateInfo
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
UpdateInfo contains resource (instance groups, etc), status and other intermediate information relevant to a node pool upgrade.
Defined Under Namespace
Classes: BlueGreenInfo
Instance Attribute Summary collapse
-
#blue_green_info ⇒ ::Google::Cloud::Container::V1beta1::NodePool::UpdateInfo::BlueGreenInfo
Information of a blue-green upgrade.
Instance Attribute Details
#blue_green_info ⇒ ::Google::Cloud::Container::V1beta1::NodePool::UpdateInfo::BlueGreenInfo
Returns Information of a blue-green upgrade.
5726 5727 5728 5729 5730 5731 5732 5733 5734 5735 5736 5737 5738 5739 5740 5741 5742 5743 5744 5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 5756 5757 5758 5759 5760 5761 5762 5763 5764 5765 5766 5767 5768 5769 5770 5771 5772 5773 5774 5775 5776 5777 5778 5779 5780 5781 5782 5783 5784 5785 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5726 class UpdateInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Information relevant to blue-green upgrade. # @!attribute [rw] phase # @return [::Google::Cloud::Container::V1beta1::NodePool::UpdateInfo::BlueGreenInfo::Phase] # Current blue-green upgrade phase. # @!attribute [rw] blue_instance_group_urls # @return [::Array<::String>] # The resource URLs of the [managed instance groups] # (/compute/docs/instance-groups/creating-groups-of-managed-instances) # associated with blue pool. # @!attribute [rw] green_instance_group_urls # @return [::Array<::String>] # The resource URLs of the [managed instance groups] # (/compute/docs/instance-groups/creating-groups-of-managed-instances) # associated with green pool. # @!attribute [rw] blue_pool_deletion_start_time # @return [::String] # Time to start deleting blue pool to complete blue-green upgrade, # in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format. # @!attribute [rw] green_pool_version # @return [::String] # Version of green pool. class BlueGreenInfo include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Phase represents the different stages blue-green upgrade is running in. module Phase # Unspecified phase. PHASE_UNSPECIFIED = 0 # blue-green upgrade has been initiated. UPDATE_STARTED = 1 # Start creating green pool nodes. CREATING_GREEN_POOL = 2 # Start cordoning blue pool nodes. CORDONING_BLUE_POOL = 3 # Start waiting after cordoning the blue pool and before draining it. WAITING_TO_DRAIN_BLUE_POOL = 8 # Start draining blue pool nodes. DRAINING_BLUE_POOL = 4 # Start soaking time after draining entire blue pool. NODE_POOL_SOAKING = 5 # Start deleting blue nodes. DELETING_BLUE_POOL = 6 # Rollback has been initiated. ROLLBACK_STARTED = 7 end end end |