Class: Google::Cloud::Container::V1beta1::PodAutoscaling
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::PodAutoscaling
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
PodAutoscaling is used for configuration of parameters for workload autoscaling.
Defined Under Namespace
Modules: HPAProfile
Instance Attribute Summary collapse
-
#hpa_profile ⇒ ::Google::Cloud::Container::V1beta1::PodAutoscaling::HPAProfile
Selected Horizontal Pod Autoscaling profile.
Instance Attribute Details
#hpa_profile ⇒ ::Google::Cloud::Container::V1beta1::PodAutoscaling::HPAProfile
Returns Selected Horizontal Pod Autoscaling profile.
8465 8466 8467 8468 8469 8470 8471 8472 8473 8474 8475 8476 8477 8478 8479 8480 8481 8482 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8465 class PodAutoscaling include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of Horizontal Pod Autoscaling profile. module HPAProfile # HPA_PROFILE_UNSPECIFIED is used when no custom HPA profile is set. HPA_PROFILE_UNSPECIFIED = 0 # Customers explicitly opt-out of HPA profiles. NONE = 1 # PERFORMANCE is used when customers opt-in to the performance HPA profile. # In this profile we support a higher number of HPAs per cluster and faster # metrics collection for workload autoscaling. PERFORMANCE = 2 end end |