Class: Google::Cloud::Container::V1beta1::RBACBindingConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings that can be created.

Instance Attribute Summary collapse

Instance Attribute Details

#enable_insecure_binding_system_authenticated::Boolean

Returns Setting this to true will allow any ClusterRoleBinding and RoleBinding with subjects system:authenticated.

Returns:

  • (::Boolean)

    Setting this to true will allow any ClusterRoleBinding and RoleBinding with subjects system:authenticated.



3411
3412
3413
3414
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3411

class RBACBindingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#enable_insecure_binding_system_unauthenticated::Boolean

Returns Setting this to true will allow any ClusterRoleBinding and RoleBinding with subjets system:anonymous or system:unauthenticated.

Returns:

  • (::Boolean)

    Setting this to true will allow any ClusterRoleBinding and RoleBinding with subjets system:anonymous or system:unauthenticated.



3411
3412
3413
3414
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3411

class RBACBindingConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end