Class: Google::Cloud::Container::V1beta1::ResourceLabels

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

Collection of Resource Manager labels.

Defined Under Namespace

Classes: LabelsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#labels::Google::Protobuf::Map{::String => ::String}

Returns Map of node label keys and node label values.

Returns:

  • (::Google::Protobuf::Map{::String => ::String})

    Map of node label keys and node label values.



1920
1921
1922
1923
1924
1925
1926
1927
1928
1929
1930
1931
1932
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1920

class ResourceLabels
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class LabelsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end