Class: Google::Cloud::Container::V1beta1::RollbackSafeUpgrade
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::RollbackSafeUpgrade
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
RollbackSafeUpgrade is the configuration for the rollback safe upgrade.
Instance Attribute Summary collapse
-
#control_plane_soak_duration ⇒ ::Google::Protobuf::Duration
A user-defined period for the cluster remains in the rollbackable state.
Instance Attribute Details
#control_plane_soak_duration ⇒ ::Google::Protobuf::Duration
Returns A user-defined period for the cluster remains in the rollbackable state. ex: {seconds: 21600}.
7799 7800 7801 7802 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7799 class RollbackSafeUpgrade include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |