Class: Google::Cloud::Container::V1beta1::RollbackSafeUpgradeStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

RollbackSafeUpgradeStatus contains the rollback-safe upgrade status of a cluster.

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Attribute Details

#control_plane_upgrade_rollback_end_time::Google::Protobuf::Timestamp

Returns The rollback-safe mode expiration time.

Returns:



8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8831

class RollbackSafeUpgradeStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode indicates the mode of the rollback-safe upgrade.
  module Mode
    # MODE_UNSPECIFIED means it's in regular upgrade mode.
    MODE_UNSPECIFIED = 0

    # KCP_MINOR_UPGRADE_ROLLBACK_SAFE_MODE means it's in rollback-safe mode
    # after a KCP minor version step-one upgrade.
    KCP_MINOR_UPGRADE_ROLLBACK_SAFE_MODE = 1
  end
end

#mode::Google::Cloud::Container::V1beta1::RollbackSafeUpgradeStatus::Mode

Returns The mode of the rollback-safe upgrade.

Returns:



8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8831

class RollbackSafeUpgradeStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode indicates the mode of the rollback-safe upgrade.
  module Mode
    # MODE_UNSPECIFIED means it's in regular upgrade mode.
    MODE_UNSPECIFIED = 0

    # KCP_MINOR_UPGRADE_ROLLBACK_SAFE_MODE means it's in rollback-safe mode
    # after a KCP minor version step-one upgrade.
    KCP_MINOR_UPGRADE_ROLLBACK_SAFE_MODE = 1
  end
end

#previous_version::String

Returns The GKE version that the cluster previously used before step-one upgrade.

Returns:

  • (::String)

    The GKE version that the cluster previously used before step-one upgrade.



8831
8832
8833
8834
8835
8836
8837
8838
8839
8840
8841
8842
8843
8844
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8831

class RollbackSafeUpgradeStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode indicates the mode of the rollback-safe upgrade.
  module Mode
    # MODE_UNSPECIFIED means it's in regular upgrade mode.
    MODE_UNSPECIFIED = 0

    # KCP_MINOR_UPGRADE_ROLLBACK_SAFE_MODE means it's in rollback-safe mode
    # after a KCP minor version step-one upgrade.
    KCP_MINOR_UPGRADE_ROLLBACK_SAFE_MODE = 1
  end
end