Class: Google::Cloud::Container::V1beta1::SandboxConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::SandboxConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
SandboxConfig contains configurations of the sandbox to use for the node.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#sandbox_type ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#type ⇒ ::Google::Cloud::Container::V1beta1::SandboxConfig::Type
Type of the sandbox to use for the node.
Instance Attribute Details
#sandbox_type ⇒ ::String
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Type of the sandbox to use for the node (e.g. 'gvisor').
1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1437 class SandboxConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of sandboxes. module Type # Default value. This should not be used. UNSPECIFIED = 0 # Run sandbox using gvisor. GVISOR = 1 end end |
#type ⇒ ::Google::Cloud::Container::V1beta1::SandboxConfig::Type
Returns Type of the sandbox to use for the node.
1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 1447 1448 1449 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1437 class SandboxConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of sandboxes. module Type # Default value. This should not be used. UNSPECIFIED = 0 # Run sandbox using gvisor. GVISOR = 1 end end |