Class: Google::Cloud::Container::V1beta1::SetMasterAuthRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::SetMasterAuthRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
SetMasterAuthRequest updates the admin password of a cluster.
Defined Under Namespace
Modules: Action
Instance Attribute Summary collapse
-
#action ⇒ ::Google::Cloud::Container::V1beta1::SetMasterAuthRequest::Action
Required.
-
#cluster_id ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#name ⇒ ::String
The name (project, location, cluster) of the cluster to set auth.
-
#project_id ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#update ⇒ ::Google::Cloud::Container::V1beta1::MasterAuth
Required.
-
#zone ⇒ ::String
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#action ⇒ ::Google::Cloud::Container::V1beta1::SetMasterAuthRequest::Action
Returns Required. The exact form of action to be taken on the master auth.
5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5013 class SetMasterAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Operation type: what type update to perform. module Action # Operation is unknown and will error out. UNKNOWN = 0 # Set the password to a user generated value. SET_PASSWORD = 1 # Generate a new password and set it to that. GENERATE_PASSWORD = 2 # Set the username. If an empty username is provided, basic authentication # is disabled for the cluster. If a non-empty username is provided, basic # authentication is enabled, with either a provided password or a generated # one. SET_USERNAME = 3 end end |
#cluster_id ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Deprecated. The name of the cluster to upgrade. This field has been deprecated and replaced by the name field.
5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5013 class SetMasterAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Operation type: what type update to perform. module Action # Operation is unknown and will error out. UNKNOWN = 0 # Set the password to a user generated value. SET_PASSWORD = 1 # Generate a new password and set it to that. GENERATE_PASSWORD = 2 # Set the username. If an empty username is provided, basic authentication # is disabled for the cluster. If a non-empty username is provided, basic # authentication is enabled, with either a provided password or a generated # one. SET_USERNAME = 3 end end |
#name ⇒ ::String
Returns The name (project, location, cluster) of the cluster to set auth.
Specified in the format projects/*/locations/*/clusters/*.
5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5013 class SetMasterAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Operation type: what type update to perform. module Action # Operation is unknown and will error out. UNKNOWN = 0 # Set the password to a user generated value. SET_PASSWORD = 1 # Generate a new password and set it to that. GENERATE_PASSWORD = 2 # Set the username. If an empty username is provided, basic authentication # is disabled for the cluster. If a non-empty username is provided, basic # authentication is enabled, with either a provided password or a generated # one. SET_USERNAME = 3 end end |
#project_id ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Deprecated. The Google Developers Console project ID or project number. This field has been deprecated and replaced by the name field.
5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5013 class SetMasterAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Operation type: what type update to perform. module Action # Operation is unknown and will error out. UNKNOWN = 0 # Set the password to a user generated value. SET_PASSWORD = 1 # Generate a new password and set it to that. GENERATE_PASSWORD = 2 # Set the username. If an empty username is provided, basic authentication # is disabled for the cluster. If a non-empty username is provided, basic # authentication is enabled, with either a provided password or a generated # one. SET_USERNAME = 3 end end |
#update ⇒ ::Google::Cloud::Container::V1beta1::MasterAuth
Returns Required. A description of the update.
5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5013 class SetMasterAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Operation type: what type update to perform. module Action # Operation is unknown and will error out. UNKNOWN = 0 # Set the password to a user generated value. SET_PASSWORD = 1 # Generate a new password and set it to that. GENERATE_PASSWORD = 2 # Set the username. If an empty username is provided, basic authentication # is disabled for the cluster. If a non-empty username is provided, basic # authentication is enabled, with either a provided password or a generated # one. SET_USERNAME = 3 end end |
#zone ⇒ ::String
This field is deprecated and may be removed in the next major version update.
Returns Deprecated. The name of the Google Compute Engine zone in which the cluster resides. This field has been deprecated and replaced by the name field.
5013 5014 5015 5016 5017 5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 5028 5029 5030 5031 5032 5033 5034 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5013 class SetMasterAuthRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Operation type: what type update to perform. module Action # Operation is unknown and will error out. UNKNOWN = 0 # Set the password to a user generated value. SET_PASSWORD = 1 # Generate a new password and set it to that. GENERATE_PASSWORD = 2 # Set the username. If an empty username is provided, basic authentication # is disabled for the cluster. If a non-empty username is provided, basic # authentication is enabled, with either a provided password or a generated # one. SET_USERNAME = 3 end end |