Class: Google::Cloud::Container::V1beta1::SlurmOperatorConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

Configuration for the Slurm Operator.

Instance Attribute Summary collapse

Instance Attribute Details

#enabled::Boolean

Returns Whether the Slurm Operator is enabled in the cluster.

Returns:

  • (::Boolean)

    Whether the Slurm Operator is enabled in the cluster.



2269
2270
2271
2272
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2269

class SlurmOperatorConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end