Class: Google::Cloud::Container::V1beta1::SoleTenantConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

SoleTenantConfig contains the NodeAffinities to specify what shared sole tenant node groups should back the node pool.

Defined Under Namespace

Classes: NodeAffinity

Instance Attribute Summary collapse

Instance Attribute Details

#min_node_cpus::Integer

Returns Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. This field can only be set if the node pool is created in a shared sole-tenant node group.

Returns:

  • (::Integer)

    Optional. The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node. This field can only be set if the node pool is created in a shared sole-tenant node group.



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1587

class SoleTenantConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the NodeAffinity key, values, and affinity operator according to
  # [shared sole tenant node group
  # affinities](https://cloud.google.com/compute/docs/nodes/sole-tenant-nodes#node_affinity_and_anti-affinity).
  # @!attribute [rw] key
  #   @return [::String]
  #     Key for NodeAffinity.
  # @!attribute [rw] operator
  #   @return [::Google::Cloud::Container::V1beta1::SoleTenantConfig::NodeAffinity::Operator]
  #     Operator for NodeAffinity.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Values for NodeAffinity.
  class NodeAffinity
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Operator allows user to specify affinity or anti-affinity for the
    # given key values.
    module Operator
      # Invalid or unspecified affinity operator.
      OPERATOR_UNSPECIFIED = 0

      # Affinity operator.
      IN = 1

      # Anti-affinity operator.
      NOT_IN = 2
    end
  end
end

#node_affinities::Array<::Google::Cloud::Container::V1beta1::SoleTenantConfig::NodeAffinity>

Returns NodeAffinities used to match to a shared sole tenant node group.

Returns:



1587
1588
1589
1590
1591
1592
1593
1594
1595
1596
1597
1598
1599
1600
1601
1602
1603
1604
1605
1606
1607
1608
1609
1610
1611
1612
1613
1614
1615
1616
1617
1618
1619
1620
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1587

class SoleTenantConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Specifies the NodeAffinity key, values, and affinity operator according to
  # [shared sole tenant node group
  # affinities](https://cloud.google.com/compute/docs/nodes/sole-tenant-nodes#node_affinity_and_anti-affinity).
  # @!attribute [rw] key
  #   @return [::String]
  #     Key for NodeAffinity.
  # @!attribute [rw] operator
  #   @return [::Google::Cloud::Container::V1beta1::SoleTenantConfig::NodeAffinity::Operator]
  #     Operator for NodeAffinity.
  # @!attribute [rw] values
  #   @return [::Array<::String>]
  #     Values for NodeAffinity.
  class NodeAffinity
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Operator allows user to specify affinity or anti-affinity for the
    # given key values.
    module Operator
      # Invalid or unspecified affinity operator.
      OPERATOR_UNSPECIFIED = 0

      # Affinity operator.
      IN = 1

      # Anti-affinity operator.
      NOT_IN = 2
    end
  end
end