Class: Google::Cloud::Container::V1beta1::TpuConfig Deprecated
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::TpuConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Deprecated.
This message is deprecated and may be removed in the next major version update.
Configuration for Cloud TPU. This message is deprecated due to the deprecation of 2VM TPU. The end of life date for 2VM TPU is 2025-04-25.
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Whether Cloud TPU integration is enabled or not.
-
#ipv4_cidr_block ⇒ ::String
IPv4 CIDR block reserved for Cloud TPU in the VPC.
-
#use_service_networking ⇒ ::Boolean
Whether to use service networking for Cloud TPU or not.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Whether Cloud TPU integration is enabled or not.
7762 7763 7764 7765 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7762 class TpuConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#ipv4_cidr_block ⇒ ::String
Returns IPv4 CIDR block reserved for Cloud TPU in the VPC.
7762 7763 7764 7765 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7762 class TpuConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#use_service_networking ⇒ ::Boolean
Returns Whether to use service networking for Cloud TPU or not.
7762 7763 7764 7765 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7762 class TpuConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |