Class: Google::Cloud::Container::V1beta1::WindowsNodeConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::WindowsNodeConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Parameters that can be configured on Windows nodes. Windows Node Config that define the parameters that will be used to configure the Windows node pool settings.
Defined Under Namespace
Modules: OSVersion
Instance Attribute Summary collapse
-
#os_version ⇒ ::Google::Cloud::Container::V1beta1::WindowsNodeConfig::OSVersion
OSVersion specifies the Windows node config to be used on the node.
Instance Attribute Details
#os_version ⇒ ::Google::Cloud::Container::V1beta1::WindowsNodeConfig::OSVersion
Returns OSVersion specifies the Windows node config to be used on the node.
406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 406 class WindowsNodeConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible OS version that can be used. module OSVersion # When OSVersion is not specified OS_VERSION_UNSPECIFIED = 0 # LTSC2019 specifies to use LTSC2019 as the Windows Servercore Base Image. OS_VERSION_LTSC2019 = 1 # LTSC2022 specifies to use LTSC2022 as the Windows Servercore Base Image. OS_VERSION_LTSC2022 = 2 end end |