Class: Google::Cloud::Container::V1beta1::WorkloadConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::WorkloadConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
WorkloadConfig defines the flags to enable or disable the workload configurations for the cluster.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#audit_mode ⇒ ::Google::Cloud::Container::V1beta1::WorkloadConfig::Mode
Sets which mode of auditing should be used for the cluster's workloads.
Instance Attribute Details
#audit_mode ⇒ ::Google::Cloud::Container::V1beta1::WorkloadConfig::Mode
Returns Sets which mode of auditing should be used for the cluster's workloads.
3562 3563 3564 3565 3566 3567 3568 3569 3570 3571 3572 3573 3574 3575 3576 3577 3578 3579 3580 3581 3582 3583 3584 3585 3586 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3562 class WorkloadConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode defines how to audit the workload configs. module Mode # Default value meaning that no mode has been specified. MODE_UNSPECIFIED = 0 # This disables Workload Configuration auditing on the cluster, # meaning that nothing is surfaced. DISABLED = 1 # Applies the default set of policy auditing to a cluster's workloads. BASIC = 4 # Surfaces configurations that are not in line with the # Pod Security Standard Baseline policy. BASELINE = 2 # Surfaces configurations that are not in line with the # Pod Security Standard Restricted policy. RESTRICTED = 3 end end |