Class: Google::Cloud::Container::V1beta1::AnonymousAuthenticationConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::AnonymousAuthenticationConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
AnonymousAuthenticationConfig defines the settings needed to limit endpoints that allow anonymous authentication.
Defined Under Namespace
Modules: Mode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::Container::V1beta1::AnonymousAuthenticationConfig::Mode
Defines the mode of limiting anonymous access in the cluster.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::Container::V1beta1::AnonymousAuthenticationConfig::Mode
Returns Defines the mode of limiting anonymous access in the cluster.
3470 3471 3472 3473 3474 3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 3485 3486 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3470 class AnonymousAuthenticationConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode defines the mode of anonymous authentication # allowed in the cluster. module Mode # Default value not specified. MODE_UNSPECIFIED = 0 # Anonymous authentication is allowed for all endpoints. ENABLED = 1 # Anonymous authentication is allowed for only health check endpoints. LIMITED = 2 end end |