Class: Google::Cloud::Container::V1beta1::ClusterPolicyConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::ClusterPolicyConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
ClusterPolicyConfig stores the configuration for cluster wide policies.
Instance Attribute Summary collapse
-
#no_standard_node_pools ⇒ ::Boolean
Denotes preventing standard node pools and requiring only autopilot node pools.
-
#no_system_impersonation ⇒ ::Boolean
Denotes preventing impersonation and CSRs for GKE System users.
-
#no_system_mutation ⇒ ::Boolean
Denotes that preventing creation and mutation of resources in GKE managed namespaces and cluster-scoped GKE managed resources .
-
#no_unsafe_webhooks ⇒ ::Boolean
Denotes preventing unsafe webhooks.
Instance Attribute Details
#no_standard_node_pools ⇒ ::Boolean
Returns Denotes preventing standard node pools and requiring only autopilot node pools.
7861 7862 7863 7864 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7861 class ClusterPolicyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#no_system_impersonation ⇒ ::Boolean
Returns Denotes preventing impersonation and CSRs for GKE System users.
7861 7862 7863 7864 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7861 class ClusterPolicyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#no_system_mutation ⇒ ::Boolean
Returns Denotes that preventing creation and mutation of resources in GKE managed namespaces and cluster-scoped GKE managed resources .
7861 7862 7863 7864 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7861 class ClusterPolicyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#no_unsafe_webhooks ⇒ ::Boolean
Returns Denotes preventing unsafe webhooks.
7861 7862 7863 7864 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7861 class ClusterPolicyConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |