Class: Google::Cloud::Container::V1beta1::ConfidentialNodes
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::ConfidentialNodes
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
ConfidentialNodes is configuration for the confidential nodes feature, which makes nodes run on confidential VMs.
Defined Under Namespace
Modules: ConfidentialInstanceType
Instance Attribute Summary collapse
-
#confidential_instance_type ⇒ ::Google::Cloud::Container::V1beta1::ConfidentialNodes::ConfidentialInstanceType
Defines the type of technology used by the confidential node.
-
#enabled ⇒ ::Boolean
Whether Confidential Nodes feature is enabled.
Instance Attribute Details
#confidential_instance_type ⇒ ::Google::Cloud::Container::V1beta1::ConfidentialNodes::ConfidentialInstanceType
Returns Defines the type of technology used by the confidential node.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7975 class ConfidentialNodes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of technology used by the confidential node. module ConfidentialInstanceType # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0 # AMD Secure Encrypted Virtualization. SEV = 1 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 2 # Intel Trust Domain eXtension. TDX = 3 end end |
#enabled ⇒ ::Boolean
Returns Whether Confidential Nodes feature is enabled.
7975 7976 7977 7978 7979 7980 7981 7982 7983 7984 7985 7986 7987 7988 7989 7990 7991 7992 7993 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7975 class ConfidentialNodes include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of technology used by the confidential node. module ConfidentialInstanceType # No type specified. Do not use this value. CONFIDENTIAL_INSTANCE_TYPE_UNSPECIFIED = 0 # AMD Secure Encrypted Virtualization. SEV = 1 # AMD Secure Encrypted Virtualization - Secure Nested Paging. SEV_SNP = 2 # Intel Trust Domain eXtension. TDX = 3 end end |