Class: Google::Cloud::Container::V1beta1::ControlPlaneEndpointsConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::ControlPlaneEndpointsConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Configuration for all of the cluster's control plane endpoints.
Defined Under Namespace
Classes: DNSEndpointConfig, IPEndpointsConfig
Instance Attribute Summary collapse
-
#dns_endpoint_config ⇒ ::Google::Cloud::Container::V1beta1::ControlPlaneEndpointsConfig::DNSEndpointConfig
DNS endpoint configuration.
-
#ip_endpoints_config ⇒ ::Google::Cloud::Container::V1beta1::ControlPlaneEndpointsConfig::IPEndpointsConfig
IP endpoints configuration.
Instance Attribute Details
#dns_endpoint_config ⇒ ::Google::Cloud::Container::V1beta1::ControlPlaneEndpointsConfig::DNSEndpointConfig
Returns DNS endpoint configuration.
8585 8586 8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 8604 8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 8633 8634 8635 8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8585 class ControlPlaneEndpointsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes the configuration of a DNS endpoint. # @!attribute [r] endpoint # @return [::String] # Output only. The cluster's DNS endpoint configuration. # A DNS format address. This is accessible from the public internet. # Ex: uid.us-central1.gke.goog. # Always present, but the behavior may change according to the value of # {::Google::Cloud::Container::V1beta1::ControlPlaneEndpointsConfig::DNSEndpointConfig#allow_external_traffic DNSEndpointConfig.allow_external_traffic}. # @!attribute [rw] allow_external_traffic # @return [::Boolean] # Controls whether user traffic is allowed over this endpoint. Note that # Google-managed services may still use the endpoint # even if this is false. # @!attribute [rw] enable_k8s_tokens_via_dns # @return [::Boolean] # Controls whether the k8s token auth is allowed via DNS. # @!attribute [rw] enable_k8s_certs_via_dns # @return [::Boolean] # Controls whether the k8s certs auth is allowed via DNS. class DNSEndpointConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # IP endpoints configuration. # @!attribute [rw] enabled # @return [::Boolean] # Controls whether to allow direct IP access. # @!attribute [rw] enable_public_endpoint # @return [::Boolean] # Controls whether the control plane allows access through a public IP. # It is invalid to specify both # [PrivateClusterConfig.enablePrivateEndpoint][] and this field at the same # time. # @!attribute [rw] global_access # @return [::Boolean] # Controls whether the control plane's private endpoint is accessible from # sources in other regions. # It is invalid to specify both # {::Google::Cloud::Container::V1beta1::PrivateClusterMasterGlobalAccessConfig#enabled PrivateClusterMasterGlobalAccessConfig.enabled} # and this field at the same time. # @!attribute [rw] authorized_networks_config # @return [::Google::Cloud::Container::V1beta1::MasterAuthorizedNetworksConfig] # Configuration of authorized networks. If enabled, restricts access to the # control plane based on source IP. # It is invalid to specify both # [Cluster.masterAuthorizedNetworksConfig][] and this field at the same # time. # @!attribute [r] public_endpoint # @return [::String] # Output only. The external IP address of this cluster's control plane. # Only populated if enabled. # @!attribute [r] private_endpoint # @return [::String] # Output only. The internal IP address of this cluster's control plane. # Only populated if enabled. # @!attribute [rw] private_endpoint_subnetwork # @return [::String] # Subnet to provision the master's private endpoint during cluster # creation. Specified in projects/*/regions/*/subnetworks/* format. It is # invalid to specify both # [PrivateClusterConfig.privateEndpointSubnetwork][] and this field at the # same time. class IPEndpointsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#ip_endpoints_config ⇒ ::Google::Cloud::Container::V1beta1::ControlPlaneEndpointsConfig::IPEndpointsConfig
Returns IP endpoints configuration.
8585 8586 8587 8588 8589 8590 8591 8592 8593 8594 8595 8596 8597 8598 8599 8600 8601 8602 8603 8604 8605 8606 8607 8608 8609 8610 8611 8612 8613 8614 8615 8616 8617 8618 8619 8620 8621 8622 8623 8624 8625 8626 8627 8628 8629 8630 8631 8632 8633 8634 8635 8636 8637 8638 8639 8640 8641 8642 8643 8644 8645 8646 8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8585 class ControlPlaneEndpointsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Describes the configuration of a DNS endpoint. # @!attribute [r] endpoint # @return [::String] # Output only. The cluster's DNS endpoint configuration. # A DNS format address. This is accessible from the public internet. # Ex: uid.us-central1.gke.goog. # Always present, but the behavior may change according to the value of # {::Google::Cloud::Container::V1beta1::ControlPlaneEndpointsConfig::DNSEndpointConfig#allow_external_traffic DNSEndpointConfig.allow_external_traffic}. # @!attribute [rw] allow_external_traffic # @return [::Boolean] # Controls whether user traffic is allowed over this endpoint. Note that # Google-managed services may still use the endpoint # even if this is false. # @!attribute [rw] enable_k8s_tokens_via_dns # @return [::Boolean] # Controls whether the k8s token auth is allowed via DNS. # @!attribute [rw] enable_k8s_certs_via_dns # @return [::Boolean] # Controls whether the k8s certs auth is allowed via DNS. class DNSEndpointConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # IP endpoints configuration. # @!attribute [rw] enabled # @return [::Boolean] # Controls whether to allow direct IP access. # @!attribute [rw] enable_public_endpoint # @return [::Boolean] # Controls whether the control plane allows access through a public IP. # It is invalid to specify both # [PrivateClusterConfig.enablePrivateEndpoint][] and this field at the same # time. # @!attribute [rw] global_access # @return [::Boolean] # Controls whether the control plane's private endpoint is accessible from # sources in other regions. # It is invalid to specify both # {::Google::Cloud::Container::V1beta1::PrivateClusterMasterGlobalAccessConfig#enabled PrivateClusterMasterGlobalAccessConfig.enabled} # and this field at the same time. # @!attribute [rw] authorized_networks_config # @return [::Google::Cloud::Container::V1beta1::MasterAuthorizedNetworksConfig] # Configuration of authorized networks. If enabled, restricts access to the # control plane based on source IP. # It is invalid to specify both # [Cluster.masterAuthorizedNetworksConfig][] and this field at the same # time. # @!attribute [r] public_endpoint # @return [::String] # Output only. The external IP address of this cluster's control plane. # Only populated if enabled. # @!attribute [r] private_endpoint # @return [::String] # Output only. The internal IP address of this cluster's control plane. # Only populated if enabled. # @!attribute [rw] private_endpoint_subnetwork # @return [::String] # Subnet to provision the master's private endpoint during cluster # creation. Specified in projects/*/regions/*/subnetworks/* format. It is # invalid to specify both # [PrivateClusterConfig.privateEndpointSubnetwork][] and this field at the # same time. class IPEndpointsConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |