Class: Google::Cloud::Container::V1beta1::DatabaseEncryption

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

Configuration of etcd encryption.

Defined Under Namespace

Modules: CurrentState, State Classes: OperationError

Instance Attribute Summary collapse

Instance Attribute Details

#current_state::Google::Cloud::Container::V1beta1::DatabaseEncryption::CurrentState (readonly)

Returns Output only. The current state of etcd encryption.

Returns:



7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
7400
7401
7402
7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7379

class DatabaseEncryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # OperationError records errors seen from CloudKMS keys
  # encountered during updates to DatabaseEncryption configuration.
  # @!attribute [rw] key_name
  #   @return [::String]
  #     CloudKMS key resource that had the error.
  # @!attribute [rw] error_message
  #   @return [::String]
  #     Description of the error seen during the operation.
  # @!attribute [rw] timestamp
  #   @return [::Google::Protobuf::Timestamp]
  #     Time when the CloudKMS error was seen.
  class OperationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of etcd encryption.
  module State
    # Should never be set
    UNKNOWN = 0

    # Secrets in etcd are encrypted.
    ENCRYPTED = 1

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    DECRYPTED = 2

    # Encryption of all objects in the storage is enabled. There is no
    # guarantee that all objects in the storage are encrypted, but eventually
    # they will be.
    ALL_OBJECTS_ENCRYPTION_ENABLED = 3
  end

  # Current State of etcd encryption.
  module CurrentState
    # Should never be set
    CURRENT_STATE_UNSPECIFIED = 0

    # Secrets in etcd are encrypted.
    CURRENT_STATE_ENCRYPTED = 7

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    CURRENT_STATE_DECRYPTED = 2

    # Encryption (or re-encryption with a different CloudKMS key)
    # of Secrets is in progress.
    CURRENT_STATE_ENCRYPTION_PENDING = 3

    # Encryption (or re-encryption with a different CloudKMS key) of Secrets in
    # etcd encountered an error.
    CURRENT_STATE_ENCRYPTION_ERROR = 4

    # De-crypting Secrets to plain text in etcd is in progress.
    CURRENT_STATE_DECRYPTION_PENDING = 5

    # De-crypting Secrets to plain text in etcd encountered an error.
    CURRENT_STATE_DECRYPTION_ERROR = 6

    # Encryption of all objects in the storage is enabled.
    # It does not guarantee that all objects in the storage are encrypted,
    # but eventually they will be.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ENABLED = 8

    # Enablement of the encryption of all objects in storage is pending.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_PENDING = 9

    # Enabling encryption of all objects in storage encountered an error.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ERROR = 10
  end
end

#decryption_keys::Array<::String> (readonly)

Returns Output only. Keys in use by the cluster for decrypting existing objects, in addition to the key in key_name.

Each item is a CloudKMS key resource.

Returns:

  • (::Array<::String>)

    Output only. Keys in use by the cluster for decrypting existing objects, in addition to the key in key_name.

    Each item is a CloudKMS key resource.



7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
7400
7401
7402
7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7379

class DatabaseEncryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # OperationError records errors seen from CloudKMS keys
  # encountered during updates to DatabaseEncryption configuration.
  # @!attribute [rw] key_name
  #   @return [::String]
  #     CloudKMS key resource that had the error.
  # @!attribute [rw] error_message
  #   @return [::String]
  #     Description of the error seen during the operation.
  # @!attribute [rw] timestamp
  #   @return [::Google::Protobuf::Timestamp]
  #     Time when the CloudKMS error was seen.
  class OperationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of etcd encryption.
  module State
    # Should never be set
    UNKNOWN = 0

    # Secrets in etcd are encrypted.
    ENCRYPTED = 1

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    DECRYPTED = 2

    # Encryption of all objects in the storage is enabled. There is no
    # guarantee that all objects in the storage are encrypted, but eventually
    # they will be.
    ALL_OBJECTS_ENCRYPTION_ENABLED = 3
  end

  # Current State of etcd encryption.
  module CurrentState
    # Should never be set
    CURRENT_STATE_UNSPECIFIED = 0

    # Secrets in etcd are encrypted.
    CURRENT_STATE_ENCRYPTED = 7

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    CURRENT_STATE_DECRYPTED = 2

    # Encryption (or re-encryption with a different CloudKMS key)
    # of Secrets is in progress.
    CURRENT_STATE_ENCRYPTION_PENDING = 3

    # Encryption (or re-encryption with a different CloudKMS key) of Secrets in
    # etcd encountered an error.
    CURRENT_STATE_ENCRYPTION_ERROR = 4

    # De-crypting Secrets to plain text in etcd is in progress.
    CURRENT_STATE_DECRYPTION_PENDING = 5

    # De-crypting Secrets to plain text in etcd encountered an error.
    CURRENT_STATE_DECRYPTION_ERROR = 6

    # Encryption of all objects in the storage is enabled.
    # It does not guarantee that all objects in the storage are encrypted,
    # but eventually they will be.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ENABLED = 8

    # Enablement of the encryption of all objects in storage is pending.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_PENDING = 9

    # Enabling encryption of all objects in storage encountered an error.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ERROR = 10
  end
end

#key_name::String

Returns Name of CloudKMS key to use for the encryption of secrets in etcd. Ex. projects/my-project/locations/global/keyRings/my-ring/cryptoKeys/my-key.

Returns:

  • (::String)

    Name of CloudKMS key to use for the encryption of secrets in etcd. Ex. projects/my-project/locations/global/keyRings/my-ring/cryptoKeys/my-key



7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
7400
7401
7402
7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7379

class DatabaseEncryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # OperationError records errors seen from CloudKMS keys
  # encountered during updates to DatabaseEncryption configuration.
  # @!attribute [rw] key_name
  #   @return [::String]
  #     CloudKMS key resource that had the error.
  # @!attribute [rw] error_message
  #   @return [::String]
  #     Description of the error seen during the operation.
  # @!attribute [rw] timestamp
  #   @return [::Google::Protobuf::Timestamp]
  #     Time when the CloudKMS error was seen.
  class OperationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of etcd encryption.
  module State
    # Should never be set
    UNKNOWN = 0

    # Secrets in etcd are encrypted.
    ENCRYPTED = 1

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    DECRYPTED = 2

    # Encryption of all objects in the storage is enabled. There is no
    # guarantee that all objects in the storage are encrypted, but eventually
    # they will be.
    ALL_OBJECTS_ENCRYPTION_ENABLED = 3
  end

  # Current State of etcd encryption.
  module CurrentState
    # Should never be set
    CURRENT_STATE_UNSPECIFIED = 0

    # Secrets in etcd are encrypted.
    CURRENT_STATE_ENCRYPTED = 7

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    CURRENT_STATE_DECRYPTED = 2

    # Encryption (or re-encryption with a different CloudKMS key)
    # of Secrets is in progress.
    CURRENT_STATE_ENCRYPTION_PENDING = 3

    # Encryption (or re-encryption with a different CloudKMS key) of Secrets in
    # etcd encountered an error.
    CURRENT_STATE_ENCRYPTION_ERROR = 4

    # De-crypting Secrets to plain text in etcd is in progress.
    CURRENT_STATE_DECRYPTION_PENDING = 5

    # De-crypting Secrets to plain text in etcd encountered an error.
    CURRENT_STATE_DECRYPTION_ERROR = 6

    # Encryption of all objects in the storage is enabled.
    # It does not guarantee that all objects in the storage are encrypted,
    # but eventually they will be.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ENABLED = 8

    # Enablement of the encryption of all objects in storage is pending.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_PENDING = 9

    # Enabling encryption of all objects in storage encountered an error.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ERROR = 10
  end
end

#last_operation_errors::Array<::Google::Cloud::Container::V1beta1::DatabaseEncryption::OperationError> (readonly)

Returns Output only. Records errors seen during DatabaseEncryption update operations.

Returns:



7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
7400
7401
7402
7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7379

class DatabaseEncryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # OperationError records errors seen from CloudKMS keys
  # encountered during updates to DatabaseEncryption configuration.
  # @!attribute [rw] key_name
  #   @return [::String]
  #     CloudKMS key resource that had the error.
  # @!attribute [rw] error_message
  #   @return [::String]
  #     Description of the error seen during the operation.
  # @!attribute [rw] timestamp
  #   @return [::Google::Protobuf::Timestamp]
  #     Time when the CloudKMS error was seen.
  class OperationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of etcd encryption.
  module State
    # Should never be set
    UNKNOWN = 0

    # Secrets in etcd are encrypted.
    ENCRYPTED = 1

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    DECRYPTED = 2

    # Encryption of all objects in the storage is enabled. There is no
    # guarantee that all objects in the storage are encrypted, but eventually
    # they will be.
    ALL_OBJECTS_ENCRYPTION_ENABLED = 3
  end

  # Current State of etcd encryption.
  module CurrentState
    # Should never be set
    CURRENT_STATE_UNSPECIFIED = 0

    # Secrets in etcd are encrypted.
    CURRENT_STATE_ENCRYPTED = 7

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    CURRENT_STATE_DECRYPTED = 2

    # Encryption (or re-encryption with a different CloudKMS key)
    # of Secrets is in progress.
    CURRENT_STATE_ENCRYPTION_PENDING = 3

    # Encryption (or re-encryption with a different CloudKMS key) of Secrets in
    # etcd encountered an error.
    CURRENT_STATE_ENCRYPTION_ERROR = 4

    # De-crypting Secrets to plain text in etcd is in progress.
    CURRENT_STATE_DECRYPTION_PENDING = 5

    # De-crypting Secrets to plain text in etcd encountered an error.
    CURRENT_STATE_DECRYPTION_ERROR = 6

    # Encryption of all objects in the storage is enabled.
    # It does not guarantee that all objects in the storage are encrypted,
    # but eventually they will be.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ENABLED = 8

    # Enablement of the encryption of all objects in storage is pending.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_PENDING = 9

    # Enabling encryption of all objects in storage encountered an error.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ERROR = 10
  end
end

#state::Google::Cloud::Container::V1beta1::DatabaseEncryption::State

Returns The desired state of etcd encryption.

Returns:



7379
7380
7381
7382
7383
7384
7385
7386
7387
7388
7389
7390
7391
7392
7393
7394
7395
7396
7397
7398
7399
7400
7401
7402
7403
7404
7405
7406
7407
7408
7409
7410
7411
7412
7413
7414
7415
7416
7417
7418
7419
7420
7421
7422
7423
7424
7425
7426
7427
7428
7429
7430
7431
7432
7433
7434
7435
7436
7437
7438
7439
7440
7441
7442
7443
7444
7445
7446
7447
7448
7449
7450
7451
7452
7453
7454
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7379

class DatabaseEncryption
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # OperationError records errors seen from CloudKMS keys
  # encountered during updates to DatabaseEncryption configuration.
  # @!attribute [rw] key_name
  #   @return [::String]
  #     CloudKMS key resource that had the error.
  # @!attribute [rw] error_message
  #   @return [::String]
  #     Description of the error seen during the operation.
  # @!attribute [rw] timestamp
  #   @return [::Google::Protobuf::Timestamp]
  #     Time when the CloudKMS error was seen.
  class OperationError
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # State of etcd encryption.
  module State
    # Should never be set
    UNKNOWN = 0

    # Secrets in etcd are encrypted.
    ENCRYPTED = 1

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    DECRYPTED = 2

    # Encryption of all objects in the storage is enabled. There is no
    # guarantee that all objects in the storage are encrypted, but eventually
    # they will be.
    ALL_OBJECTS_ENCRYPTION_ENABLED = 3
  end

  # Current State of etcd encryption.
  module CurrentState
    # Should never be set
    CURRENT_STATE_UNSPECIFIED = 0

    # Secrets in etcd are encrypted.
    CURRENT_STATE_ENCRYPTED = 7

    # Secrets in etcd are stored in plain text (at etcd level) - this is
    # unrelated to Compute Engine level full disk encryption.
    CURRENT_STATE_DECRYPTED = 2

    # Encryption (or re-encryption with a different CloudKMS key)
    # of Secrets is in progress.
    CURRENT_STATE_ENCRYPTION_PENDING = 3

    # Encryption (or re-encryption with a different CloudKMS key) of Secrets in
    # etcd encountered an error.
    CURRENT_STATE_ENCRYPTION_ERROR = 4

    # De-crypting Secrets to plain text in etcd is in progress.
    CURRENT_STATE_DECRYPTION_PENDING = 5

    # De-crypting Secrets to plain text in etcd encountered an error.
    CURRENT_STATE_DECRYPTION_ERROR = 6

    # Encryption of all objects in the storage is enabled.
    # It does not guarantee that all objects in the storage are encrypted,
    # but eventually they will be.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ENABLED = 8

    # Enablement of the encryption of all objects in storage is pending.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_PENDING = 9

    # Enabling encryption of all objects in storage encountered an error.
    CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ERROR = 10
  end
end