Class: Google::Cloud::Container::V1beta1::DisruptionEvent
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::DisruptionEvent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
DisruptionEvent is a notification sent to customers about the disruption event of a resource.
Defined Under Namespace
Modules: DisruptionType Classes: PdbBlockedPod
Instance Attribute Summary collapse
-
#disruption_type ⇒ ::Google::Cloud::Container::V1beta1::DisruptionEvent::DisruptionType
The type of the disruption event.
-
#pdb_blocked_node ⇒ ::String
The node whose drain is blocked by PDB.
-
#pdb_blocked_pod ⇒ ::Array<::Google::Cloud::Container::V1beta1::DisruptionEvent::PdbBlockedPod>
The pods whose evictions are blocked by PDB.
-
#pdb_violation_timeout ⇒ ::Google::Protobuf::Duration
The timeout in seconds for which the node drain is blocked by PDB.
Instance Attribute Details
#disruption_type ⇒ ::Google::Cloud::Container::V1beta1::DisruptionEvent::DisruptionType
Returns The type of the disruption event.
8182 8183 8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8182 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_blocked_node ⇒ ::String
Returns The node whose drain is blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.
8182 8183 8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8182 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_blocked_pod ⇒ ::Array<::Google::Cloud::Container::V1beta1::DisruptionEvent::PdbBlockedPod>
Returns The pods whose evictions are blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.
8182 8183 8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8182 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_violation_timeout ⇒ ::Google::Protobuf::Duration
Returns The timeout in seconds for which the node drain is blocked by PDB. After this timeout, pods are forcefully evicted. This field is only populated when event_type is POD_PDB_VIOLATION.
8182 8183 8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 8197 8198 8199 8200 8201 8202 8203 8204 8205 8206 8207 8208 8209 8210 8211 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8182 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |