Class: Google::Cloud::Container::V1beta1::DisruptionEvent
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::DisruptionEvent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
DisruptionEvent is a notification sent to customers about the disruption event of a resource.
Defined Under Namespace
Modules: DisruptionType Classes: PdbBlockedPod
Instance Attribute Summary collapse
-
#disruption_type ⇒ ::Google::Cloud::Container::V1beta1::DisruptionEvent::DisruptionType
The type of the disruption event.
-
#pdb_blocked_node ⇒ ::String
The node whose drain is blocked by PDB.
-
#pdb_blocked_pod ⇒ ::Array<::Google::Cloud::Container::V1beta1::DisruptionEvent::PdbBlockedPod>
The pods whose evictions are blocked by PDB.
-
#pdb_violation_timeout ⇒ ::Google::Protobuf::Duration
The timeout in seconds for which the node drain is blocked by PDB.
Instance Attribute Details
#disruption_type ⇒ ::Google::Cloud::Container::V1beta1::DisruptionEvent::DisruptionType
Returns The type of the disruption event.
8142 8143 8144 8145 8146 8147 8148 8149 8150 8151 8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8142 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_blocked_node ⇒ ::String
Returns The node whose drain is blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.
8142 8143 8144 8145 8146 8147 8148 8149 8150 8151 8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8142 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_blocked_pod ⇒ ::Array<::Google::Cloud::Container::V1beta1::DisruptionEvent::PdbBlockedPod>
Returns The pods whose evictions are blocked by PDB. This field is set for both POD_PDB_VIOLATION and POD_NOT_ENOUGH_PDB event.
8142 8143 8144 8145 8146 8147 8148 8149 8150 8151 8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8142 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |
#pdb_violation_timeout ⇒ ::Google::Protobuf::Duration
Returns The timeout in seconds for which the node drain is blocked by PDB. After this timeout, pods are forcefully evicted. This field is only populated when event_type is POD_PDB_VIOLATION.
8142 8143 8144 8145 8146 8147 8148 8149 8150 8151 8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 8170 8171 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8142 class DisruptionEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The namespace/name of the pod whose eviction is blocked by PDB. # @!attribute [rw] namespace # @return [::String] # The namespace of the pod. # @!attribute [rw] name # @return [::String] # The name of the pod. class PdbBlockedPod include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The type of the disruption event. module DisruptionType # DISRUPTION_TYPE_UNSPECIFIED indicates the disruption type is unspecified. DISRUPTION_TYPE_UNSPECIFIED = 0 # POD_NOT_ENOUGH_PDB indicates there are still running pods # on the node during node drain because their evictions are blocked by PDB. POD_NOT_ENOUGH_PDB = 1 # POD_PDB_VIOLATION indicates that there are force pod # evictions during node drain which violate the PDB. POD_PDB_VIOLATION = 2 end end |