Class: Google::Cloud::Container::V1beta1::Fleet

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

Fleet is the fleet configuration for the cluster.

Defined Under Namespace

Modules: MembershipType

Instance Attribute Summary collapse

Instance Attribute Details

#membership::String (readonly)

Returns Output only. The full resource name of the registered fleet membership of the cluster, in the format //gkehub.googleapis.com/projects/*/locations/*/memberships/*.

Returns:

  • (::String)

    Output only. The full resource name of the registered fleet membership of the cluster, in the format //gkehub.googleapis.com/projects/*/locations/*/memberships/*.



8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8502

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # MembershipType describes if the membership supports all features or only
  # lightweight compatible ones.
  module MembershipType
    # The MembershipType is not set.
    MEMBERSHIP_TYPE_UNSPECIFIED = 0

    # The membership supports only lightweight compatible features.
    LIGHTWEIGHT = 1
  end
end

#membership_type::Google::Cloud::Container::V1beta1::Fleet::MembershipType

Returns The type of the cluster's fleet membership.

Returns:



8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8502

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # MembershipType describes if the membership supports all features or only
  # lightweight compatible ones.
  module MembershipType
    # The MembershipType is not set.
    MEMBERSHIP_TYPE_UNSPECIFIED = 0

    # The membership supports only lightweight compatible features.
    LIGHTWEIGHT = 1
  end
end

#pre_registered::Boolean (readonly)

Returns Output only. Whether the cluster has been registered through the fleet API.

Returns:

  • (::Boolean)

    Output only. Whether the cluster has been registered through the fleet API.



8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8502

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # MembershipType describes if the membership supports all features or only
  # lightweight compatible ones.
  module MembershipType
    # The MembershipType is not set.
    MEMBERSHIP_TYPE_UNSPECIFIED = 0

    # The membership supports only lightweight compatible features.
    LIGHTWEIGHT = 1
  end
end

#project::String

Returns The Fleet host project(project ID or project number) where this cluster will be registered to. This field cannot be changed after the cluster has been registered.

Returns:

  • (::String)

    The Fleet host project(project ID or project number) where this cluster will be registered to. This field cannot be changed after the cluster has been registered.



8502
8503
8504
8505
8506
8507
8508
8509
8510
8511
8512
8513
8514
8515
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 8502

class Fleet
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # MembershipType describes if the membership supports all features or only
  # lightweight compatible ones.
  module MembershipType
    # The MembershipType is not set.
    MEMBERSHIP_TYPE_UNSPECIFIED = 0

    # The membership supports only lightweight compatible features.
    LIGHTWEIGHT = 1
  end
end