Class: Google::Cloud::Container::V1beta1::HostMaintenancePolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

HostMaintenancePolicy contains the maintenance policy for the hosts on which the GKE VMs run on.

Defined Under Namespace

Modules: MaintenanceInterval Classes: OpportunisticMaintenanceStrategy

Instance Attribute Summary collapse

Instance Attribute Details

#maintenance_interval::Google::Cloud::Container::V1beta1::HostMaintenancePolicy::MaintenanceInterval

Returns Specifies the frequency of planned maintenance events.

Returns:



1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1804

class HostMaintenancePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Strategy that will trigger maintenance on behalf of the customer.
  # @!attribute [rw] node_idle_time_window
  #   @return [::Google::Protobuf::Duration]
  #     The amount of time that a node can remain idle (no customer owned
  #     workloads running), before triggering maintenance.
  # @!attribute [rw] maintenance_availability_window
  #   @return [::Google::Protobuf::Duration]
  #     The window of time that opportunistic maintenance can run. Example: A
  #     setting of 14 days implies that opportunistic maintenance can only be ran
  #     in the 2 weeks leading up to the scheduled maintenance date. Setting 28
  #     days allows opportunistic maintenance to run at any time in the scheduled
  #     maintenance window (all `PERIODIC` maintenance is set 28 days in
  #     advance).
  # @!attribute [rw] min_nodes_per_pool
  #   @return [::Integer]
  #     The minimum nodes required to be available in a pool. Blocks maintenance
  #     if it would cause the number of running nodes to dip below this value.
  class OpportunisticMaintenanceStrategy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Allows selecting how infrastructure upgrades should be applied to the
  # cluster or node pool.
  module MaintenanceInterval
    # The maintenance interval is not explicitly specified.
    MAINTENANCE_INTERVAL_UNSPECIFIED = 0

    # Nodes are eligible to receive infrastructure and hypervisor updates as
    # they become available.  This may result in more maintenance operations
    # (live migrations or terminations) for the node than the PERIODIC option.
    AS_NEEDED = 1

    # Nodes receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean underlying VMs will
    # take longer to receive an update than if it was configured for
    # AS_NEEDED.  Security updates will still be applied as soon
    # as they are available.
    PERIODIC = 2
  end
end

#opportunistic_maintenance_strategy::Google::Cloud::Container::V1beta1::HostMaintenancePolicy::OpportunisticMaintenanceStrategy

Returns Strategy that will trigger maintenance on behalf of the customer.

Returns:



1804
1805
1806
1807
1808
1809
1810
1811
1812
1813
1814
1815
1816
1817
1818
1819
1820
1821
1822
1823
1824
1825
1826
1827
1828
1829
1830
1831
1832
1833
1834
1835
1836
1837
1838
1839
1840
1841
1842
1843
1844
1845
1846
1847
1848
1849
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1804

class HostMaintenancePolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Strategy that will trigger maintenance on behalf of the customer.
  # @!attribute [rw] node_idle_time_window
  #   @return [::Google::Protobuf::Duration]
  #     The amount of time that a node can remain idle (no customer owned
  #     workloads running), before triggering maintenance.
  # @!attribute [rw] maintenance_availability_window
  #   @return [::Google::Protobuf::Duration]
  #     The window of time that opportunistic maintenance can run. Example: A
  #     setting of 14 days implies that opportunistic maintenance can only be ran
  #     in the 2 weeks leading up to the scheduled maintenance date. Setting 28
  #     days allows opportunistic maintenance to run at any time in the scheduled
  #     maintenance window (all `PERIODIC` maintenance is set 28 days in
  #     advance).
  # @!attribute [rw] min_nodes_per_pool
  #   @return [::Integer]
  #     The minimum nodes required to be available in a pool. Blocks maintenance
  #     if it would cause the number of running nodes to dip below this value.
  class OpportunisticMaintenanceStrategy
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Allows selecting how infrastructure upgrades should be applied to the
  # cluster or node pool.
  module MaintenanceInterval
    # The maintenance interval is not explicitly specified.
    MAINTENANCE_INTERVAL_UNSPECIFIED = 0

    # Nodes are eligible to receive infrastructure and hypervisor updates as
    # they become available.  This may result in more maintenance operations
    # (live migrations or terminations) for the node than the PERIODIC option.
    AS_NEEDED = 1

    # Nodes receive infrastructure and hypervisor updates on a periodic basis,
    # minimizing the number of maintenance operations (live migrations or
    # terminations) on an individual VM.  This may mean underlying VMs will
    # take longer to receive an update than if it was configured for
    # AS_NEEDED.  Security updates will still be applied as soon
    # as they are available.
    PERIODIC = 2
  end
end