Class: Google::Cloud::Container::V1beta1::IstioConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::IstioConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Configuration options for Istio addon.
Defined Under Namespace
Modules: IstioAuthMode
Instance Attribute Summary collapse
-
#auth ⇒ ::Google::Cloud::Container::V1beta1::IstioConfig::IstioAuthMode
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#disabled ⇒ ::Boolean
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
Instance Attribute Details
#auth ⇒ ::Google::Cloud::Container::V1beta1::IstioConfig::IstioAuthMode
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns The specified Istio auth mode, either none, or mutual TLS.
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2401 class IstioConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Istio auth mode, https://istio.io/docs/concepts/security/mutual-tls.html module IstioAuthMode # auth not enabled AUTH_NONE = 0 # auth mutual TLS enabled AUTH_MUTUAL_TLS = 1 end end |
#disabled ⇒ ::Boolean
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Whether Istio is enabled for this cluster.
2401 2402 2403 2404 2405 2406 2407 2408 2409 2410 2411 2412 2413 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 2401 class IstioConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Istio auth mode, https://istio.io/docs/concepts/security/mutual-tls.html module IstioAuthMode # auth not enabled AUTH_NONE = 0 # auth mutual TLS enabled AUTH_MUTUAL_TLS = 1 end end |