Class: Google::Cloud::Container::V1beta1::LinuxNodeConfig::CustomNodeInit
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::LinuxNodeConfig::CustomNodeInit
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Support for running custom init code while bootstrapping nodes.
Defined Under Namespace
Classes: InitScript
Instance Attribute Summary collapse
-
#init_script ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::CustomNodeInit::InitScript
Optional.
Instance Attribute Details
#init_script ⇒ ::Google::Cloud::Container::V1beta1::LinuxNodeConfig::CustomNodeInit::InitScript
Returns Optional. The init script to be executed on the node.
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 158 class CustomNodeInit include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # InitScript provide a simply bash script to be executed on the node. # @!attribute [rw] gcs_uri # @return [::String] # The Cloud Storage URI for storing the init script. # Format: gs://BUCKET_NAME/OBJECT_NAME # The service account on the node pool must have read access to the # object. # User can't configure both gcs_uri and gcp_secret_manager_secret_uri. # @!attribute [rw] gcs_generation # @return [::Integer] # The generation of the init script stored in Gloud Storage. # This is the required field to identify the version of the # init script. # User can get the genetaion from # `gcloud storage objects describe gs://BUCKET_NAME/OBJECT_NAME # --format="value(generation)"` or from the "Version history" tab of the # object in the Cloud Console UI. # @!attribute [rw] args # @return [::Array<::String>] # Optional. The optional arguments line to be passed to the init script. # @!attribute [rw] gcp_secret_manager_secret_uri # @return [::String] # The resource name of the secret manager secret hosting the init script. # Both global and regional secrets are supported with format below: # Global secret: projects/\\{project}/secrets/\\{secret}/versions/\\{version} # Regional secret: # projects/\\{project}/locations/\\{location}/secrets/\\{secret}/versions/\\{version} # Example: projects/1234567890/secrets/script_1/versions/1. # Accept version number only, not support version alias. # User can't configure both gcp_secret_manager_secret_uri and gcs_uri. class InitScript include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |