Class: Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Represents the Maintenance exclusion option.
Defined Under Namespace
Modules: EndTimeBehavior, Scope
Instance Attribute Summary collapse
-
#end_time_behavior ⇒ ::Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions::EndTimeBehavior
EndTimeBehavior specifies the behavior of the exclusion end time.
-
#scope ⇒ ::Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions::Scope
Scope specifies the upgrade scope which upgrades are blocked by the exclusion.
Instance Attribute Details
#end_time_behavior ⇒ ::Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions::EndTimeBehavior
Returns EndTimeBehavior specifies the behavior of the exclusion end time.
6003 6004 6005 6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 6028 6029 6030 6031 6032 6033 6034 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6003 class MaintenanceExclusionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope of exclusion. module Scope # NO_UPGRADES excludes all upgrades, including patch upgrades and minor # upgrades across control planes and nodes. This is the default exclusion # behavior. NO_UPGRADES = 0 # NO_MINOR_UPGRADES excludes all minor upgrades for the cluster, only # patches are allowed. NO_MINOR_UPGRADES = 1 # NO_MINOR_OR_NODE_UPGRADES excludes all minor upgrades for the cluster, # and also exclude all node pool upgrades. Only control # plane patches are allowed. NO_MINOR_OR_NODE_UPGRADES = 2 end # EndTimeBehavior specifies the behavior of the exclusion end time. module EndTimeBehavior # END_TIME_BEHAVIOR_UNSPECIFIED is the default behavior, which is fixed # end time. END_TIME_BEHAVIOR_UNSPECIFIED = 0 # UNTIL_END_OF_SUPPORT means the exclusion will be in effect until the end # of the support of the cluster's current version. UNTIL_END_OF_SUPPORT = 1 end end |
#scope ⇒ ::Google::Cloud::Container::V1beta1::MaintenanceExclusionOptions::Scope
Returns Scope specifies the upgrade scope which upgrades are blocked by the exclusion.
6003 6004 6005 6006 6007 6008 6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 6028 6029 6030 6031 6032 6033 6034 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6003 class MaintenanceExclusionOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Scope of exclusion. module Scope # NO_UPGRADES excludes all upgrades, including patch upgrades and minor # upgrades across control planes and nodes. This is the default exclusion # behavior. NO_UPGRADES = 0 # NO_MINOR_UPGRADES excludes all minor upgrades for the cluster, only # patches are allowed. NO_MINOR_UPGRADES = 1 # NO_MINOR_OR_NODE_UPGRADES excludes all minor upgrades for the cluster, # and also exclude all node pool upgrades. Only control # plane patches are allowed. NO_MINOR_OR_NODE_UPGRADES = 2 end # EndTimeBehavior specifies the behavior of the exclusion end time. module EndTimeBehavior # END_TIME_BEHAVIOR_UNSPECIFIED is the default behavior, which is fixed # end time. END_TIME_BEHAVIOR_UNSPECIFIED = 0 # UNTIL_END_OF_SUPPORT means the exclusion will be in effect until the end # of the support of the cluster's current version. UNTIL_END_OF_SUPPORT = 1 end end |