Class: Google::Cloud::Container::V1beta1::MaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::MaintenanceWindow
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
MaintenanceWindow defines the maintenance window to be used for the cluster.
Defined Under Namespace
Classes: MaintenanceExclusionsEntry
Instance Attribute Summary collapse
-
#daily_maintenance_window ⇒ ::Google::Cloud::Container::V1beta1::DailyMaintenanceWindow
DailyMaintenanceWindow specifies a daily maintenance operation window.
-
#maintenance_exclusions ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Container::V1beta1::TimeWindow}
Exceptions to maintenance window.
-
#recurring_maintenance_window ⇒ ::Google::Cloud::Container::V1beta1::RecurringMaintenanceWindow
RecurringMaintenanceWindow specifies some number of recurring time periods for maintenance to occur.
-
#recurring_window ⇒ ::Google::Cloud::Container::V1beta1::RecurringTimeWindow
RecurringWindow specifies some number of recurring time periods for maintenance to occur.
Instance Attribute Details
#daily_maintenance_window ⇒ ::Google::Cloud::Container::V1beta1::DailyMaintenanceWindow
Returns DailyMaintenanceWindow specifies a daily maintenance operation window.
Note: The following fields are mutually exclusive: daily_maintenance_window, recurring_window, recurring_maintenance_window. If a field in that set is populated, all other fields in the set will automatically be cleared.
5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5964 class MaintenanceWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Container::V1beta1::TimeWindow] class MaintenanceExclusionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#maintenance_exclusions ⇒ ::Google::Protobuf::Map{::String => ::Google::Cloud::Container::V1beta1::TimeWindow}
Returns Exceptions to maintenance window. Non-emergency maintenance should not occur in these windows.
5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5964 class MaintenanceWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Container::V1beta1::TimeWindow] class MaintenanceExclusionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#recurring_maintenance_window ⇒ ::Google::Cloud::Container::V1beta1::RecurringMaintenanceWindow
Returns RecurringMaintenanceWindow specifies some number of recurring time periods for maintenance to occur. The time windows may be overlapping. If no maintenance windows are set, maintenance can occur at any time. Alternative to RecurringWindow, with renamed fields.
Note: The following fields are mutually exclusive: recurring_maintenance_window, daily_maintenance_window, recurring_window. If a field in that set is populated, all other fields in the set will automatically be cleared.
5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5964 class MaintenanceWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Container::V1beta1::TimeWindow] class MaintenanceExclusionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#recurring_window ⇒ ::Google::Cloud::Container::V1beta1::RecurringTimeWindow
Returns RecurringWindow specifies some number of recurring time periods for maintenance to occur. The time windows may be overlapping. If no maintenance windows are set, maintenance can occur at any time.
Note: The following fields are mutually exclusive: recurring_window, daily_maintenance_window, recurring_maintenance_window. If a field in that set is populated, all other fields in the set will automatically be cleared.
5964 5965 5966 5967 5968 5969 5970 5971 5972 5973 5974 5975 5976 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 5964 class MaintenanceWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::Google::Cloud::Container::V1beta1::TimeWindow] class MaintenanceExclusionsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |