Class: Google::Cloud::Container::V1beta1::NetworkTierConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::NetworkTierConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
NetworkTierConfig contains network tier information.
Defined Under Namespace
Modules: NetworkTier
Instance Attribute Summary collapse
-
#network_tier ⇒ ::Google::Cloud::Container::V1beta1::NetworkTierConfig::NetworkTier
Network tier configuration.
Instance Attribute Details
#network_tier ⇒ ::Google::Cloud::Container::V1beta1::NetworkTierConfig::NetworkTier
Returns Network tier configuration.
9024 9025 9026 9027 9028 9029 9030 9031 9032 9033 9034 9035 9036 9037 9038 9039 9040 9041 9042 9043 9044 9045 9046 9047 9048 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 9024 class NetworkTierConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Network tier configuration. module NetworkTier # By default, use project-level configuration. When unspecified, the # behavior defaults to NETWORK_TIER_DEFAULT. For cluster updates, this # implies no action (no-op). NETWORK_TIER_UNSPECIFIED = 0 # Default network tier. Use project-level configuration. User can specify # this value, meaning they want to keep the same behaviour as before # cluster level network tier configuration is introduced. This field # ensures backward compatibility for the network tier of cluster resources, # such as node pools and load balancers, for their external IP addresses. NETWORK_TIER_DEFAULT = 1 # Premium network tier. NETWORK_TIER_PREMIUM = 2 # Standard network tier. NETWORK_TIER_STANDARD = 3 end end |