Class: Google::Cloud::Container::V1beta1::NodeKubeletConfig::CrashLoopBackOffConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::NodeKubeletConfig::CrashLoopBackOffConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Contains config to modify node-level parameters for container restart behavior.
Instance Attribute Summary collapse
-
#max_container_restart_period ⇒ ::String
Optional.
Instance Attribute Details
#max_container_restart_period ⇒ ::String
Returns Optional. The maximum duration the backoff delay can accrue to for container restarts, minimum 1 second, maximum 300 seconds. If not set, defaults to the internal crashloopbackoff maximum.
The string must be a sequence of decimal numbers, each with optional fraction and a unit suffix, such as "300ms". Valid time units are "ns", "us" (or "µs"), "ms", "s", "m", "h".
See https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#configurable-container-restart-delay for more details.
634 635 636 637 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 634 class CrashLoopBackOffConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |