Class: Google::Cloud::Container::V1beta1::NotificationConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

NotificationConfig is the configuration of notifications.

Defined Under Namespace

Modules: EventType Classes: Filter, PubSub

Instance Attribute Summary collapse

Instance Attribute Details

#pubsub::Google::Cloud::Container::V1beta1::NotificationConfig::PubSub

Returns Notification config for Pub/Sub.

Returns:



7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
7924
7925
7926
7927
7928
7929
7930
7931
7932
7933
7934
7935
7936
7937
7938
7939
7940
7941
7942
7943
7944
7945
7946
7947
7948
7949
7950
7951
7952
7953
7954
7955
7956
7957
7958
7959
7960
7961
7962
7963
7964
7965
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7913

class NotificationConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Pub/Sub specific notification config.
  # @!attribute [rw] enabled
  #   @return [::Boolean]
  #     Enable notifications for Pub/Sub.
  # @!attribute [rw] topic
  #   @return [::String]
  #     The desired Pub/Sub topic to which notifications will be
  #     sent by GKE. Format is `projects/{project}/topics/{topic}`.
  # @!attribute [rw] filter
  #   @return [::Google::Cloud::Container::V1beta1::NotificationConfig::Filter]
  #     Allows filtering to one or more specific event types. If no filter is
  #     specified, or if a filter is specified with no event types, all event
  #     types will be sent
  class PubSub
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Allows filtering to one or more specific event types. If event types are
  # present, those and only those event types will be transmitted to the
  # cluster. Other types will be skipped. If no filter is specified, or no
  # event types are present, all event types will be sent
  # @!attribute [rw] event_type
  #   @return [::Array<::Google::Cloud::Container::V1beta1::NotificationConfig::EventType>]
  #     Event types to allowlist.
  class Filter
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Types of notifications currently supported. Can be used to filter what
  # notifications are sent.
  module EventType
    # Not set, will be ignored.
    EVENT_TYPE_UNSPECIFIED = 0

    # Corresponds with UpgradeAvailableEvent.
    UPGRADE_AVAILABLE_EVENT = 1

    # Corresponds with UpgradeEvent.
    UPGRADE_EVENT = 2

    # Corresponds with SecurityBulletinEvent.
    SECURITY_BULLETIN_EVENT = 3

    # Corresponds with UpgradeInfoEvent.
    UPGRADE_INFO_EVENT = 4
  end
end