Class: Google::Cloud::Container::V1beta1::PodSnapshotConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::PodSnapshotConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.
Instance Attribute Summary collapse
-
#enabled ⇒ ::Boolean
Whether or not the Pod Snapshots feature is enabled.
Instance Attribute Details
#enabled ⇒ ::Boolean
Returns Whether or not the Pod Snapshots feature is enabled.
9112 9113 9114 9115 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 9112 class PodSnapshotConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |