Class: Google::Cloud::Container::V1beta1::RecurringMaintenanceWindow
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::RecurringMaintenanceWindow
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Represents an arbitrary window of time that recurs. Alternative to RecurringTimeWindow, with renamed fields.
Instance Attribute Summary collapse
-
#delay_until ⇒ ::Google::Type::Date
Optional.
-
#recurrence ⇒ ::String
Required.
-
#window_duration ⇒ ::Google::Protobuf::Duration
Required.
-
#window_start_time ⇒ ::Google::Type::TimeOfDay
Required.
Instance Attribute Details
#delay_until ⇒ ::Google::Type::Date
Returns Optional. Windows will not be scheduled before that day. Depending on the recurrence, this may be the date the first window appears. Days are measured in the UTC timezone. This setting must be used when INTERVAL>1 or FREQ=WEEKLY/MONTHLY and no BYDAY specified.
6109 6110 6111 6112 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6109 class RecurringMaintenanceWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#recurrence ⇒ ::String
Returns Required. An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how this window reccurs.
For example, to have something repeat every weekday, you'd use:
FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR
To repeat some window daily (equivalent to the DailyMaintenanceWindow):
FREQ=DAILY
For the first weekend of every month:
FREQ=MONTHLY;BYSETPOS=1;BYDAY=SA,SU
The FREQ values of HOURLY, MINUTELY, and SECONDLY are not supported.
6109 6110 6111 6112 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6109 class RecurringMaintenanceWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#window_duration ⇒ ::Google::Protobuf::Duration
Returns Required. Duration of the window.
6109 6110 6111 6112 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6109 class RecurringMaintenanceWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#window_start_time ⇒ ::Google::Type::TimeOfDay
Returns Required. Start time of the window on days that it is scheduled, assuming UTC timezone.
6109 6110 6111 6112 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6109 class RecurringMaintenanceWindow include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |