Class: Google::Cloud::Container::V1beta1::ReleaseChannel
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::ReleaseChannel
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
ReleaseChannel indicates which release channel a cluster is subscribed to. Release channels are arranged in order of risk.
When a cluster is subscribed to a release channel, Google maintains both the master version and the node version. Node auto-upgrade defaults to true and cannot be disabled.
Defined Under Namespace
Modules: Channel
Instance Attribute Summary collapse
-
#channel ⇒ ::Google::Cloud::Container::V1beta1::ReleaseChannel::Channel
Channel specifies which release channel the cluster is subscribed to.
Instance Attribute Details
#channel ⇒ ::Google::Cloud::Container::V1beta1::ReleaseChannel::Channel
Returns channel specifies which release channel the cluster is subscribed to.
7748 7749 7750 7751 7752 7753 7754 7755 7756 7757 7758 7759 7760 7761 7762 7763 7764 7765 7766 7767 7768 7769 7770 7771 7772 7773 7774 7775 7776 7777 7778 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7748 class ReleaseChannel include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible values for 'channel'. module Channel # No channel specified. UNSPECIFIED = 0 # RAPID channel is offered on an early access basis for customers who want # to test new releases. # # WARNING: Versions available in the RAPID Channel may be subject to # unresolved issues with no known workaround and are not subject to any # SLAs. RAPID = 1 # Clusters subscribed to REGULAR receive versions that are considered GA # quality. REGULAR is intended for production users who want to take # advantage of new features. REGULAR = 2 # Clusters subscribed to STABLE receive versions that are known to be # stable and reliable in production. STABLE = 3 # Clusters subscribed to EXTENDED receive extended support and availability # for versions which are known to be stable and reliable in production. EXTENDED = 4 end end |