Class: Google::Cloud::Container::V1beta1::ReservationAffinity

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

ReservationAffinity is the configuration of desired reservation which instances could take capacity from.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#consume_reservation_type::Google::Cloud::Container::V1beta1::ReservationAffinity::Type

Returns Corresponds to the type of reservation consumption.

Returns:



1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1535

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates whether to consume capacity from a reservation or not.
  module Type
    # Default value. This should not be used.
    UNSPECIFIED = 0

    # Do not consume from any reserved capacity.
    NO_RESERVATION = 1

    # Consume any reservation available.
    ANY_RESERVATION = 2

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 3
  end
end

#key::String

Returns Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, specify "compute.googleapis.com/reservation-name" as the key and specify the name of your reservation as its value.

Returns:

  • (::String)

    Corresponds to the label key of a reservation resource. To target a SPECIFIC_RESERVATION by name, specify "compute.googleapis.com/reservation-name" as the key and specify the name of your reservation as its value.



1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1535

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates whether to consume capacity from a reservation or not.
  module Type
    # Default value. This should not be used.
    UNSPECIFIED = 0

    # Do not consume from any reserved capacity.
    NO_RESERVATION = 1

    # Consume any reservation available.
    ANY_RESERVATION = 2

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 3
  end
end

#values::Array<::String>

Returns Corresponds to the label value(s) of reservation resource(s).

Returns:

  • (::Array<::String>)

    Corresponds to the label value(s) of reservation resource(s).



1535
1536
1537
1538
1539
1540
1541
1542
1543
1544
1545
1546
1547
1548
1549
1550
1551
1552
1553
1554
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 1535

class ReservationAffinity
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Indicates whether to consume capacity from a reservation or not.
  module Type
    # Default value. This should not be used.
    UNSPECIFIED = 0

    # Do not consume from any reserved capacity.
    NO_RESERVATION = 1

    # Consume any reservation available.
    ANY_RESERVATION = 2

    # Must consume from a specific reservation. Must specify key value fields
    # for specifying the reservations.
    SPECIFIC_RESERVATION = 3
  end
end