Class: Google::Cloud::Container::V1beta1::ResourceUsageExportConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::ResourceUsageExportConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
Configuration for exporting cluster resource usages.
Defined Under Namespace
Classes: BigQueryDestination, ConsumptionMeteringConfig
Instance Attribute Summary collapse
-
#bigquery_destination ⇒ ::Google::Cloud::Container::V1beta1::ResourceUsageExportConfig::BigQueryDestination
Configuration to use BigQuery as usage export destination.
-
#consumption_metering_config ⇒ ::Google::Cloud::Container::V1beta1::ResourceUsageExportConfig::ConsumptionMeteringConfig
Configuration to enable resource consumption metering.
-
#enable_network_egress_metering ⇒ ::Boolean
Whether to enable network egress metering for this cluster.
Instance Attribute Details
#bigquery_destination ⇒ ::Google::Cloud::Container::V1beta1::ResourceUsageExportConfig::BigQueryDestination
Returns Configuration to use BigQuery as usage export destination.
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7467 class ResourceUsageExportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters for using BigQuery as the destination of resource usage export. # @!attribute [rw] dataset_id # @return [::String] # The ID of a BigQuery Dataset. class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters for controlling consumption metering. # @!attribute [rw] enabled # @return [::Boolean] # Whether to enable consumption metering for this cluster. If enabled, a # second BigQuery table will be created to hold resource consumption # records. class ConsumptionMeteringConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#consumption_metering_config ⇒ ::Google::Cloud::Container::V1beta1::ResourceUsageExportConfig::ConsumptionMeteringConfig
Returns Configuration to enable resource consumption metering.
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7467 class ResourceUsageExportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters for using BigQuery as the destination of resource usage export. # @!attribute [rw] dataset_id # @return [::String] # The ID of a BigQuery Dataset. class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters for controlling consumption metering. # @!attribute [rw] enabled # @return [::Boolean] # Whether to enable consumption metering for this cluster. If enabled, a # second BigQuery table will be created to hold resource consumption # records. class ConsumptionMeteringConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#enable_network_egress_metering ⇒ ::Boolean
Returns Whether to enable network egress metering for this cluster. If enabled, a daemonset will be created in the cluster to meter network egress traffic.
7467 7468 7469 7470 7471 7472 7473 7474 7475 7476 7477 7478 7479 7480 7481 7482 7483 7484 7485 7486 7487 7488 7489 7490 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 7467 class ResourceUsageExportConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parameters for using BigQuery as the destination of resource usage export. # @!attribute [rw] dataset_id # @return [::String] # The ID of a BigQuery Dataset. class BigQueryDestination include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Parameters for controlling consumption metering. # @!attribute [rw] enabled # @return [::Boolean] # Whether to enable consumption metering for this cluster. If enabled, a # second BigQuery table will be created to hold resource consumption # records. class ConsumptionMeteringConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |