Class: Google::Cloud::Container::V1beta1::SecurityPostureConfig
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::SecurityPostureConfig
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API.
Defined Under Namespace
Modules: Mode, VulnerabilityMode
Instance Attribute Summary collapse
-
#mode ⇒ ::Google::Cloud::Container::V1beta1::SecurityPostureConfig::Mode
Sets which mode to use for Security Posture features.
-
#vulnerability_mode ⇒ ::Google::Cloud::Container::V1beta1::SecurityPostureConfig::VulnerabilityMode
Sets which mode to use for vulnerability scanning.
Instance Attribute Details
#mode ⇒ ::Google::Cloud::Container::V1beta1::SecurityPostureConfig::Mode
Returns Sets which mode to use for Security Posture features.
3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3622 class SecurityPostureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode defines enablement mode for GKE Security posture features. module Mode # Default value not specified. MODE_UNSPECIFIED = 0 # Disables Security Posture features on the cluster. DISABLED = 1 # Applies Security Posture features on the cluster. BASIC = 2 # Deprecated: Security Posture Enterprise features are no longer supported. # For more details, see # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation. # # Applies the Security Posture off cluster Enterprise level features. ENTERPRISE = 3 end # VulnerabilityMode defines enablement mode for vulnerability scanning. module VulnerabilityMode # Default value not specified. VULNERABILITY_MODE_UNSPECIFIED = 0 # Disables vulnerability scanning on the cluster. VULNERABILITY_DISABLED = 1 # Deprecated: Basic vulnerability scanning is no longer supported. # For more details, see # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation. # # Applies basic vulnerability scanning on the cluster. VULNERABILITY_BASIC = 2 # Applies the Security Posture's vulnerability on cluster Enterprise level # features. VULNERABILITY_ENTERPRISE = 3 end end |
#vulnerability_mode ⇒ ::Google::Cloud::Container::V1beta1::SecurityPostureConfig::VulnerabilityMode
Returns Sets which mode to use for vulnerability scanning.
3622 3623 3624 3625 3626 3627 3628 3629 3630 3631 3632 3633 3634 3635 3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3622 class SecurityPostureConfig include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Mode defines enablement mode for GKE Security posture features. module Mode # Default value not specified. MODE_UNSPECIFIED = 0 # Disables Security Posture features on the cluster. DISABLED = 1 # Applies Security Posture features on the cluster. BASIC = 2 # Deprecated: Security Posture Enterprise features are no longer supported. # For more details, see # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation. # # Applies the Security Posture off cluster Enterprise level features. ENTERPRISE = 3 end # VulnerabilityMode defines enablement mode for vulnerability scanning. module VulnerabilityMode # Default value not specified. VULNERABILITY_MODE_UNSPECIFIED = 0 # Disables vulnerability scanning on the cluster. VULNERABILITY_DISABLED = 1 # Deprecated: Basic vulnerability scanning is no longer supported. # For more details, see # https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation. # # Applies basic vulnerability scanning on the cluster. VULNERABILITY_BASIC = 2 # Applies the Security Posture's vulnerability on cluster Enterprise level # features. VULNERABILITY_ENTERPRISE = 3 end end |