Class: Google::Cloud::Container::V1beta1::StatusCondition
- Inherits:
-
Object
- Object
- Google::Cloud::Container::V1beta1::StatusCondition
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/container/v1beta1/cluster_service.rb
Overview
StatusCondition describes why a cluster or a node pool has a certain status (e.g., ERROR or DEGRADED).
Defined Under Namespace
Modules: Code
Instance Attribute Summary collapse
-
#canonical_code ⇒ ::Google::Rpc::Code
Canonical code of the condition.
-
#code ⇒ ::Google::Cloud::Container::V1beta1::StatusCondition::Code
deprecated
Deprecated.
This field is deprecated and may be removed in the next major version update.
-
#message ⇒ ::String
Human-friendly representation of the condition.
Instance Attribute Details
#canonical_code ⇒ ::Google::Rpc::Code
Returns Canonical code of the condition.
6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6920 class StatusCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Code for each condition # @deprecated This enum is deprecated and may be removed in the next major version update. module Code # UNKNOWN indicates a generic condition. UNKNOWN = 0 # GCE_STOCKOUT indicates that Google Compute Engine resources are # temporarily unavailable. GCE_STOCKOUT = 1 # GKE_SERVICE_ACCOUNT_DELETED indicates that the user deleted their robot # service account. GKE_SERVICE_ACCOUNT_DELETED = 2 # Google Compute Engine quota was exceeded. GCE_QUOTA_EXCEEDED = 3 # Cluster state was manually changed by an SRE due to a system logic error. SET_BY_OPERATOR = 4 # Unable to perform an encrypt operation against the CloudKMS key used for # etcd level encryption. CLOUD_KMS_KEY_ERROR = 7 # Cluster CA is expiring soon. CA_EXPIRING = 9 # Node service account is missing permissions. NODE_SERVICE_ACCOUNT_MISSING_PERMISSIONS = 10 # Cloud KMS key version used for etcd level encryption has been destroyed. # This is a permanent error. CLOUD_KMS_KEY_DESTROYED = 11 end end |
#code ⇒ ::Google::Cloud::Container::V1beta1::StatusCondition::Code
Deprecated.
This field is deprecated and may be removed in the next major version update.
Returns Machine-friendly representation of the condition Deprecated. Use canonical_code instead.
6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6920 class StatusCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Code for each condition # @deprecated This enum is deprecated and may be removed in the next major version update. module Code # UNKNOWN indicates a generic condition. UNKNOWN = 0 # GCE_STOCKOUT indicates that Google Compute Engine resources are # temporarily unavailable. GCE_STOCKOUT = 1 # GKE_SERVICE_ACCOUNT_DELETED indicates that the user deleted their robot # service account. GKE_SERVICE_ACCOUNT_DELETED = 2 # Google Compute Engine quota was exceeded. GCE_QUOTA_EXCEEDED = 3 # Cluster state was manually changed by an SRE due to a system logic error. SET_BY_OPERATOR = 4 # Unable to perform an encrypt operation against the CloudKMS key used for # etcd level encryption. CLOUD_KMS_KEY_ERROR = 7 # Cluster CA is expiring soon. CA_EXPIRING = 9 # Node service account is missing permissions. NODE_SERVICE_ACCOUNT_MISSING_PERMISSIONS = 10 # Cloud KMS key version used for etcd level encryption has been destroyed. # This is a permanent error. CLOUD_KMS_KEY_DESTROYED = 11 end end |
#message ⇒ ::String
Returns Human-friendly representation of the condition.
6920 6921 6922 6923 6924 6925 6926 6927 6928 6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 6945 6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 |
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 6920 class StatusCondition include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Code for each condition # @deprecated This enum is deprecated and may be removed in the next major version update. module Code # UNKNOWN indicates a generic condition. UNKNOWN = 0 # GCE_STOCKOUT indicates that Google Compute Engine resources are # temporarily unavailable. GCE_STOCKOUT = 1 # GKE_SERVICE_ACCOUNT_DELETED indicates that the user deleted their robot # service account. GKE_SERVICE_ACCOUNT_DELETED = 2 # Google Compute Engine quota was exceeded. GCE_QUOTA_EXCEEDED = 3 # Cluster state was manually changed by an SRE due to a system logic error. SET_BY_OPERATOR = 4 # Unable to perform an encrypt operation against the CloudKMS key used for # etcd level encryption. CLOUD_KMS_KEY_ERROR = 7 # Cluster CA is expiring soon. CA_EXPIRING = 9 # Node service account is missing permissions. NODE_SERVICE_ACCOUNT_MISSING_PERMISSIONS = 10 # Cloud KMS key version used for etcd level encryption has been destroyed. # This is a permanent error. CLOUD_KMS_KEY_DESTROYED = 11 end end |