Class: Google::Cloud::Container::V1beta1::WorkloadConfig

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/container/v1beta1/cluster_service.rb

Overview

WorkloadConfig defines the flags to enable or disable the workload configurations for the cluster.

Defined Under Namespace

Modules: Mode

Instance Attribute Summary collapse

Instance Attribute Details

#audit_mode::Google::Cloud::Container::V1beta1::WorkloadConfig::Mode

Returns Sets which mode of auditing should be used for the cluster's workloads.

Returns:



3541
3542
3543
3544
3545
3546
3547
3548
3549
3550
3551
3552
3553
3554
3555
3556
3557
3558
3559
3560
3561
3562
3563
3564
3565
# File 'proto_docs/google/container/v1beta1/cluster_service.rb', line 3541

class WorkloadConfig
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Mode defines how to audit the workload configs.
  module Mode
    # Default value meaning that no mode has been specified.
    MODE_UNSPECIFIED = 0

    # This disables Workload Configuration auditing on the cluster,
    # meaning that nothing is surfaced.
    DISABLED = 1

    # Applies the default set of policy auditing to a cluster's workloads.
    BASIC = 4

    # Surfaces configurations that are not in line with the
    # Pod Security Standard Baseline policy.
    BASELINE = 2

    # Surfaces configurations that are not in line with the
    # Pod Security Standard Restricted policy.
    RESTRICTED = 3
  end
end